// Copyright 2017 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Package gophers is a list of names, emails, and Github usernames of people
// from the Go git repos and issue trackers.
package gophers

import (
	"strings"

	"golang.org/x/build/gerrit"
)

type Person struct {
	Name    string   // "Foo Bar"
	Github  string   // "FooBar" (orig case, no '@')
	Emails  []string // all lower
	Googler bool
}

func strSliceContains(ss []string, s string) bool {
	for _, v := range ss {
		if v == s {
			return true
		}
	}
	return false
}

func (p *Person) mergeIDs(ids ...string) {
	for _, id := range ids {
		switch {
		case strings.HasPrefix(id, "@"):
			p.Github = id[1:]
			idToPerson[strings.ToLower(id)] = p
		case strings.Contains(id, "@"):
			email := strings.ToLower(id)
			if !strSliceContains(p.Emails, email) {
				p.Emails = append(p.Emails, email)
			}
			idToPerson[email] = p
			if strings.HasSuffix(email, "@golang.org") || strings.HasSuffix(email, "@google.com") {
				p.Googler = true
			}
		case id == "*goog":
			p.Googler = true
		default:
			p.Name = id
			idToPerson[strings.ToLower(id)] = p
		}
	}
}

// keys are "@lowercasegithub", "lowercase name", "lowercase@email.com".
var idToPerson = map[string]*Person{}

func GetPerson(id string) *Person {
	return idToPerson[strings.ToLower(id)]
}

func GetGerritPerson(ai gerrit.AccountInfo) *Person {
	if p := GetPerson(ai.Name); p != nil {
		return p
	}
	if p := GetPerson(ai.Email); p != nil {
		return p
	}
	return nil
}

func addPerson(ids ...string) *Person {
	var p *Person
	for _, id := range ids {
		p = GetPerson(id)
		if p != nil {
			break
		}
	}
	if p == nil {
		p = &Person{}
	}
	p.mergeIDs(ids...)
	return p
}

func init() {
	addPerson("9.nashi", "9.nashi@gmail.com", "@80nashi")
	addPerson("Aamir Khan", "syst3m.w0rm@gmail.com", "@syst3mw0rm")
	addPerson("Aaron France", "aaron.l.france@gmail.com", "@AeroNotix")
	addPerson("Aaron Jacobs", "jacobsa@google.com", "@jacobsa")
	addPerson("Aaron Kemp", "kemp.aaron@gmail.com", "@writeonlymemory")
	addPerson("Aaron Torres", "tcboox@gmail.com", "@agtorre")
	addPerson("Aaron Zinman", "aaron@azinman.com", "@azinman")
	addPerson("Abe Haskins", "abeisgreat@abeisgreat.com")
	addPerson("Abhinav Gupta", "abhinav.g90@gmail.com", "@abhinav")
	addPerson("Adam Langley", "agl@golang.org", "@agl")
	addPerson("Adin Scannell", "ascannell@google.com")
	addPerson("Adrian O'Grady", "elpollouk@gmail.com", "@elpollouk")
	addPerson("Agis Anastasopoulos", "agis.anast@gmail.com", "@agis")
	addPerson("Ahmet Alp Balkan", "ahmetb@google.com", "@ahmetb")
	addPerson("Ahmy Yulrizka", "yulrizka@gmail.com", "@yulrizka")
	addPerson("Aiden Scandella", "ai@uber.com", "@sectioneight")
	addPerson("Ainar Garipov", "gugl.zadolbal@gmail.com", "@ainar-g")
	addPerson("Aishraj", "aishraj@users.noreply.github.com", "@aishraj")
	addPerson("Akihiko Odaki", "akihiko.odaki.4i@stu.hosei.ac.jp")
	addPerson("Akihiro Suda", "suda.kyoto@gmail.com", "@AkihiroSuda")
	addPerson("Alan Donovan", "adonovan@google.com")
	addPerson("Alan Donovan", "adonovan@google.com", "@alandonovan")
	addPerson("Alan Donovan", "alan@alandonovan.net", "@adonovan")
	addPerson("Alan Gardner", "alanctgardner@gmail.com")
	addPerson("Alan Shreve", "alan@inconshreveable.com", "@inconshreveable")
	addPerson("Albert Smith", "albert@horde.today")
	addPerson("Albert Strasheim", "fullung@gmail.com", "@alberts")
	addPerson("Albert Yu", "yukinying@gmail.com", "@yukinying")
	addPerson("Alberto Bertogli", "albertito@blitiri.com.ar", "@albertito")
	addPerson("Alberto Donizetti", "alb.donizetti@gmail.com", "@ALTree")
	addPerson("Alberto García Hierro", "alberto@garciahierro.com", "@fiam")
	addPerson("Aleksandar Dezelin", "dezelin@gmail.com", "@dezelin")
	addPerson("Aleksandr Demakin", "alexander.demakin@gmail.com", "@avdva")
	addPerson("Alessandro Arzilli", "alessandro.arzilli@gmail.com", "@aarzilli")
	addPerson("Alessandro Baffa", "alessandro.baffa@gmail.com", "@alebaffa")
	addPerson("Alex A Skinner", "alex@lx.lc")
	addPerson("Alex Brainman", "alex.brainman@gmail.com", "@alexbrainman")
	addPerson("Alex Bramley", "a.bramley@gmail.com", "@fluffle")
	addPerson("Alex Browne", "stephenalexbrowne@gmail.com", "@albrow")
	addPerson("Alex Carol", "alex.carol.c@gmail.com", "@alexcarol")
	addPerson("Alex Crawford", "alex@acrawford.com")
	addPerson("Alex Flint", "alex.flint@gmail.com")
	addPerson("Alex Jin", "toalexjin@gmail.com", "@toalexjin")
	addPerson("Alex Plugaru", "alex@plugaru.org", "@xarg")
	addPerson("Alex Schroeder", "alex@gnu.org", "@kensanata")
	addPerson("Alex Sergeyev", "abc@alexsergeyev.com", "@asergeyev")
	addPerson("Alex Stoddard", "alex.stoddard@comcast.net")
	addPerson("Alex Vaghin", "crhyme@google.com")
	addPerson("Alex Vaghin", "ddos@google.com")
	addPerson("Alex Vaghin", "ddos@google.com", "@x1ddos")
	addPerson("Alexander Döring", "email@alexd.ch", "@alexd765")
	addPerson("Alexander Guz", "kalimatas@gmail.com", "@kalimatas")
	addPerson("Alexander Kauer", "alexander@affine.space", "@kaueraal")
	addPerson("Alexander Kucherenko", "alxkchr@gmail.com")
	addPerson("Alexander Kuleshov", "kuleshovmail@gmail.com")
	addPerson("Alexander Larsson", "alexander.larsson@gmail.com", "@alexlarsson")
	addPerson("Alexander Menzhinsky", "amenzhinsky@gmail.com", "@amenzhinsky")
	addPerson("Alexander Milyutin", "alexander.milyutin@lazada.com")
	addPerson("Alexander Morozov", "lk4d4math@gmail.com", "@LK4D4")
	addPerson("Alexander Neumann", "alexander@bumpern.de", "@fd0")
	addPerson("Alexander Orlov", "alexander.orlov@loxal.net", "@loxal")
	addPerson("Alexander Polcyn", "apolcyn@google.com", "@apolcyn")
	addPerson("Alexander Reece", "awreece@gmail.com", "@awreece")
	addPerson("Alexander Shopov", "ash@kambanaria.org", "@alshopov")
	addPerson("Alexander Zhavnerchik", "alex.vizor@gmail.com", "@alxzh")
	addPerson("Alexander Zolotov", "goldifit@gmail.com", "@zolotov")
	addPerson("Alexandre Cesaro", "alexandre.cesaro@gmail.com", "@alexcesaro")
	addPerson("Alexandre Fiori", "fiorix@gmail.com", "@fiorix")
	addPerson("Alexandre Normand", "alexandre.normand@gmail.com", "@alexandre-normand")
	addPerson("Alexandru Moșoi", "alexandru@mosoi.ro")
	addPerson("Alexandru Moșoi", "brtzsnr@gmail.com", "@brtzsnr")
	addPerson("Alexandru Moșoi", "mosoi@google.com")
	addPerson("Alexei Sholik", "alcosholik@gmail.com", "@alco")
	addPerson("Alexey Borzenkov", "snaury@gmail.com", "@snaury")
	addPerson("Alexey Neganov", "neganovalexey@gmail.com", "@neganovalexey")
	addPerson("Alexey Nezhdanov", "snakeru@gmail.com")
	addPerson("Alexey Palazhchenko", "alexey.palazhchenko@gmail.com", "@AlekSi")
	addPerson("Alexis Hunt", "lexer@google.com")
	addPerson("Alexis Imperial-Legrand", "ail@google.com", "@ailg")
	addPerson("Aliaksandr Valialkin", "valyala@gmail.com", "@valyala")
	addPerson("Alif Rachmawadi", "subosito@gmail.com", "@subosito")
	addPerson("Allan Simon", "allan.simon@supinfo.com", "@allan-simon")
	addPerson("Alok Menghrajani", "alok.menghrajani@gmail.com", "@alokmenghrajani")
	addPerson("Amanuel Bogale", "abogale2@gmail.com")
	addPerson("Amir Mohammad Saied", "amir@gluegadget.com", "@amir")
	addPerson("Ammar Bandukwala", "ammar@ammar.io")
	addPerson("Amrut Joshi", "amrut.joshi@gmail.com", "@rumple")
	addPerson("Anders Pearson", "anders@columbia.edu", "@thraxil")
	addPerson("Andrea Spadaccini", "spadaccio@google.com", "@lupino3")
	addPerson("Andreas Auernhamer", "andreas_golang@mail.de")
	addPerson("Andreas Auernhammer", "aead@mail.de", "@aead")
	addPerson("Andreas Auernhammer", "enceve@mail.de")
	addPerson("Andreas Jellinghaus", "andreas@ionisiert.de", "@tolonuga")
	addPerson("Andreas Litt", "andreas.litt@gmail.com")
	addPerson("Andrei Korzhevskii", "a.korzhevskiy@gmail.com", "@nordligulv")
	addPerson("Andres Erbsen", "andres.erbsen@gmail.com")
	addPerson("Andrew Austin", "andrewaclt@gmail.com", "@andrewaustin")
	addPerson("Andrew Benton", "andrewmbenton@gmail.com", "@andrewmbenton")
	addPerson("Andrew Bonventre", "andybons@gmail.com", "@andybons")
	addPerson("Andrew Ekstedt", "andrew.ekstedt@gmail.com", "@magical")
	addPerson("Andrew Etter", "andrew.etter@gmail.com", "@andrewetter")
	addPerson("Andrew Gerrand", "adg@golang.org", "@adg")
	addPerson("Andrew Gerrand", "nf@wh3rd.net", "@nf")
	addPerson("Andrew Harding", "andrew@spacemonkey.com", "@azdagron")
	addPerson("Andrew M Bursavich", "abursavich@gmail.com", "@abursavich")
	addPerson("Andrew Pilloud", "andrewpilloud@igneoussystems.com", "@apilloud")
	addPerson("Andrew Pogrebnoy", "absourd.noise@gmail.com", "@dAdAbird")
	addPerson("Andrew Pritchard", "awpritchard@gmail.com", "@awpr")
	addPerson("Andrew Radev", "andrey.radev@gmail.com", "@AndrewRadev")
	addPerson("Andrew Skiba", "skibaa@gmail.com", "@skibaa")
	addPerson("Andrew Szeto", "andrew@jabagawee.com", "@jabagawee")
	addPerson("Andrew Wilkins", "axwalk@gmail.com", "@axw")
	addPerson("Andrew Williams", "williams.andrew@gmail.com", "@williamsandrew")
	addPerson("Andrey Petrov", "andrey.petrov@shazow.net", "@shazow")
	addPerson("Andris Valums", "avalums.spam@linelane.com")
	addPerson("Andriy Lytvynov", "lytvynov.a.v@gmail.com", "@awly")
	addPerson("Andy Balholm", "andy@balholm.com", "@andybalholm")
	addPerson("Andy Balholm", "andybalholm@gmail.com")
	addPerson("Andy Bursavich", "bursavich@google.com")
	addPerson("Andy Davis", "andy@bigandian.com", "@bigandian")
	addPerson("Andy Finkenstadt", "afinkenstadt@zynga.com", "@afinkenstadt")
	addPerson("Andy Maloney", "asmaloney@gmail.com", "@asmaloney")
	addPerson("Anfernee Yongkun Gui", "anfernee.gui@gmail.com", "@anfernee")
	addPerson("Angelo Bulfone", "mbulfone@gmail.com", "@boomshroom")
	addPerson("Anh Hai Trinh", "anh.hai.trinh@gmail.com", "@aht")
	addPerson("Anmol Sethi", "anmol@aubble.com", "@nhooyr")
	addPerson("Anschel Schaffer-Cohen", "anschelsc@gmail.com", "@anschelsc")
	addPerson("Anthony Canino", "anthony.canino1@gmail.com", "@anthonycanino1")
	addPerson("Anthony Eufemio", "anthony.eufemio@gmail.com", "@tymat")
	addPerson("Anthony Martin", "ality@pbrane.org", "@ality")
	addPerson("Anthony Pesch", "inolen@gmail.com")
	addPerson("Anthony Romano", "anthony.romano@coreos.com")
	addPerson("Anthony Starks", "ajstarks@gmail.com", "@ajstarks")
	addPerson("Antoine Martin", "antoine97.martin@gmail.com", "@alarsyo")
	addPerson("Antonio Bibiano", "antbbn@gmail.com", "@antbbn")
	addPerson("Antonio Murdaca", "runcom@redhat.com", "@runcom")
	addPerson("Aram Hăvărneanu", "aram@mgk.ro", "@4ad")
	addPerson("Arlo Breault", "arlolra@gmail.com", "@arlolra")
	addPerson("Arnaud Ysmal", "stacktic@netbsd.org", "@stacktic")
	addPerson("Arne Hormann", "arnehormann@gmail.com", "@arnehormann")
	addPerson("Arnout Engelen", "arnout@bzzt.net")
	addPerson("Aron Nopanen", "aron.nopanen@gmail.com", "@aroneous")
	addPerson("Artyom Pervukhin", "artyom.pervukhin@gmail.com", "@artyom")
	addPerson("Arvindh Rajesh Tamilmani", "art@a-30.net", "@arvindht")
	addPerson("Asad Mehmood", "asad78611@googlemail.com")
	addPerson("Asim Shankar", "asimshankar@gmail.com", "@asimshankar")
	addPerson("Atin M", "amalaviy@akamai.com", "@amalaviy")
	addPerson("Ato Araki", "ato.araki@gmail.com", "@atotto")
	addPerson("Attila Tajti", "attila.tajti@gmail.com")
	addPerson("Audrey Lim", "audreylh@gmail.com", "@audreylim")
	addPerson("Augusto Roman", "aroman@gmail.com", "@augustoroman")
	addPerson("Aulus Egnatius Varialus", "varialus@gmail.com", "@varialus")
	addPerson("Austin Clements", "austin@google.com", "@aclements")
	addPerson("Aymerick", "aymerick@jehanne.org", "@aymerick")
	addPerson("Baiju Muthukadan", "baiju.m.mail@gmail.com", "@baijum")
	addPerson("Balazs Lecz", "leczb@google.com", "@leczb")
	addPerson("Bartek Plotka", "bwplotka@gmail.com")
	addPerson("Ben Burkert", "ben@benburkert.com", "@benburkert")
	addPerson("Ben Fried", "ben.fried@gmail.com", "@benfried")
	addPerson("Ben Lubar", "ben.lubar@gmail.com", "@BenLubar")
	addPerson("Ben Lynn", "benlynn@gmail.com", "@blynn")
	addPerson("Ben Olive", "sionide21@gmail.com", "@sionide21")
	addPerson("Ben Shi", "powerman1st@163.com", "@benshi001")
	addPerson("Benjamin Black", "b@b3k.us", "@b")
	addPerson("Benjamin Prosnitz", "bprosnitz@google.com", "@bprosnitz")
	addPerson("Benjamin Wester", "bwester@squareup.com", "@bwester")
	addPerson("Benny Siegert", "bsiegert@gmail.com", "@bsiegert")
	addPerson("Benny Siegert", "bsiegert@google.com", "@bsiegert")
	addPerson("Benoit Sigoure", "tsunanet@gmail.com", "@tsuna")
	addPerson("Bernd Fix", "brf@hoi-polloi.org")
	addPerson("Bill Neubauer", "wcn@google.com")
	addPerson("Bill O'Farrell", "billo@ca.ibm.com", "@wgo")
	addPerson("Bill Thiede", "couchmoney@gmail.com", "@wathiede", "*goog")
	addPerson("Billie H. Cleek", "bhcleek@gmail.com", "@bhcleek")
	addPerson("Billy Lynch", "wlynch@google.com", "@wlynch")
	addPerson("Blake Gentry", "blakesgentry@gmail.com", "@bgentry")
	addPerson("Blake Mizerany", "blake.mizerany@gmail.com", "@bmizerany")
	addPerson("Blixt", "me@blixt.nyc", "@blixt")
	addPerson("Bobby Powers", "bobbypowers@gmail.com", "@bpowers")
	addPerson("Bodo Junglas", "bodo.junglas@leanovate.de")
	addPerson("Boris Nagaev", "nagaev@google.com")
	addPerson("Brad Fitzpatrick", "bradfitz@golang.org", "brad@danga.com", "@bradfitz")
	addPerson("Brad Jones", "rbjones@google.com")
	addPerson("Brad Whitaker", "brad.whitaker@gmail.com")
	addPerson("Braden Bassingthwaite", "bbassingthwaite@vendasta.com")
	addPerson("Brady Catherman", "brady@gmail.com")
	addPerson("Brady Sullivan", "brady@bsull.com", "@d1str0")
	addPerson("Brandon Bennett", "bbennett@fb.com", "@nemith")
	addPerson("Brandon Gilmore", "varz@google.com", "@bgilmore")
	addPerson("Brendan Ashworth", "brendan.ashworth@me.com")
	addPerson("Brendan Daniel Tracey", "tracey.brendan@gmail.com", "@btracey")
	addPerson("Brett Cannon", "bcannon@gmail.com", "@brettcannon")
	addPerson("Brian Dellisanti", "briandellisanti@gmail.com", "@briandellisanti")
	addPerson("Brian G. Merrell", "bgmerrell@gmail.com", "@bgmerrell")
	addPerson("Brian Gitonga Marete", "bgm@google.com", "@marete")
	addPerson("Brian Gitonga Marete", "marete@toshnix.com", "@marete")
	addPerson("Brian Kennedy", "btkennedy@gmail.com", "@briantkennedy")
	addPerson("Brian Ketelsen", "bketelsen@gmail.com", "@bketelsen")
	addPerson("Brian Slesinskya", "skybrian@google.com", "@skybrian")
	addPerson("Brian Smith", "ohohvi@gmail.com", "@sirwart")
	addPerson("Brian Starke", "brian.starke@gmail.com", "@brianstarke")
	addPerson("Brian Starkey", "stark3y@gmail.com")
	addPerson("Bruno Clermont", "bruno.clermont@gmail.com")
	addPerson("Bryan Alexander", "kozical@msn.com", "@Kozical")
	addPerson("Bryan C. Mills", "bcmills@google.com", "@bcmills")
	addPerson("Bryan Chan", "bryan.chan@ca.ibm.com", "@bryanpkc")
	addPerson("Bryan Ford", "brynosaurus@gmail.com", "@bford")
	addPerson("Bryan Mills", "bcmills@google.com", "@bcmills")
	addPerson("Bryan Turley", "bryanturley@gmail.com")
	addPerson("Caine Tighe", "arctanofyourface@gmail.com", "@nilnilnil")
	addPerson("Caio Marcelo de Oliveira Filho", "caio.oliveira@intel.com", "@cmarcelo")
	addPerson("Caleb Spare", "cespare@gmail.com", "@cespare")
	addPerson("Cameron Howey", "chowey@ualberta.net")
	addPerson("Carl Chatfield", "carlchatfield@gmail.com", "@0xfaded")
	addPerson("Carl Henrik Lunde", "chlunde@ifi.uio.no")
	addPerson("Carl Jackson", "carl@stripe.com", "@carl-stripe")
	addPerson("Carl Johnson", "me@carlmjohnson.net", "@carlmjohnson")
	addPerson("Carl Mastrangelo", "notcarl@google.com", "@carl-mastrangelo")
	addPerson("Carlisia Campos", "carlisia@grokkingtech.io", "@carlisia")
	addPerson("Carlo Alberto Ferraris", "cafxx@strayorange.com", "@CAFxX")
	addPerson("Carlos C", "uldericofilho@gmail.com", "@ucirello")
	addPerson("Carlos Castillo", "cookieo9@gmail.com", "@cookieo9")
	addPerson("Carlos Eduardo Seo", "cseo@linux.vnet.ibm.com", "@ceseo")
	addPerson("Carolyn Van Slyck", "me@carolynvanslyck.com", "@carolynvs")
	addPerson("Casey Marshall", "casey.marshall@gmail.com", "@cmars")
	addPerson("Casey Smith", "smithc@homesandland.com")
	addPerson("Catalin Nicutar", "cnicutar@google.com")
	addPerson("Catalin Patulea", "catalinp@google.com", "@cpatulea")
	addPerson("Cedric Staub", "cs@squareup.com", "@csstaub")
	addPerson("Cezar Sa Espinola", "cezarsa@gmail.com", "@cezarsa")
	addPerson("ChaiShushan", "chaishushan@gmail.com", "@chai2010")
	addPerson("Charles Weill", "weill@google.com", "@cweill")
	addPerson("Charlie Dorian", "cldorian@gmail.com", "@cldorian")
	addPerson("Cheng-Lung Sung", "clsung@gmail.com", "@clsung")
	addPerson("Cherry Zhang", "cherryyz@google.com", "@cherrymui")
	addPerson("Chew Choon Keat", "choonkeat@gmail.com", "@choonkeat")
	addPerson("Chintan Sheth", "shethchintan7@gmail.com")
	addPerson("Chris Biscardi", "chris@christopherbiscardi.com", "@ChristopherBiscardi")
	addPerson("Chris Broadfoot", "cbro@golang.org", "cbro@google.com", "@broady")
	addPerson("Chris Dollin", "ehog.hedge@gmail.com", "@ehedgehog")
	addPerson("Chris Farmiloe", "chrisfarms@gmail.com", "@chrisfarms")
	addPerson("Chris Hines", "chris.cs.guy@gmail.com", "@ChrisHines")
	addPerson("Chris J Arges", "christopherarges@gmail.com")
	addPerson("Chris Jones", "chris@cjones.org", "@cjyar")
	addPerson("Chris Kastorff", "encryptio@gmail.com", "@encryptio")
	addPerson("Chris Lennert", "calennert@gmail.com", "@calennert")
	addPerson("Chris Manghane", "cmang@golang.org", "@paranoiacblack")
	addPerson("Chris McGee", "sirnewton_01@yahoo.ca", "@sirnewton01")
	addPerson("Chris Raynor", "raynor@google.com")
	addPerson("Chris Roche", "rodaine@gmail.com", "@rodaine")
	addPerson("Chris Stockton", "chrisstocktonaz@gmail.com")
	addPerson("Chris Zou", "chriszou@ca.ibm.com", "@ChrisXZou")
	addPerson("Christian Couder", "chriscool@tuxfamily.org", "@chriscool")
	addPerson("Christian Himpel", "chressie@googlemail.com", "@chressie")
	addPerson("Christian Mauduit", "ufoot@ufoot.org")
	addPerson("Christoph Hack", "christoph@tux21b.org", "@tux21b")
	addPerson("Christopher Boumenot", "chrboum@microsoft.com")
	addPerson("Christopher Cahoon", "chris.cahoon@gmail.com", "@ccahoon")
	addPerson("Christopher Guiney", "chris@guiney.net", "@chrisguiney")
	addPerson("Christopher Nelson", "nadiasvertex@gmail.com", "@nadiasvertex")
	addPerson("Christopher Nielsen", "m4dh4tt3r@gmail.com", "@m4dh4tt3r")
	addPerson("Christopher Redden", "christopher.redden@gmail.com", "@topherredden")
	addPerson("Christopher Wedgwood", "cw@f00f.org", "@cwedgwood")
	addPerson("Christy Perez", "christy@linux.vnet.ibm.com", "@clnperez")
	addPerson("Cixtor", "cixtords@gmail.com", "@cixtor")
	addPerson("Clement Skau", "clementskau@gmail.com", "@cskau")
	addPerson("Clément Denis", "clement@altirnao.com")
	addPerson("Coda Hale", "coda.hale@gmail.com")
	addPerson("Colby Ranger", "cranger@google.com", "@crangeratgoogle")
	addPerson("Colin Cross", "ccross@android.com", "@colincross")
	addPerson("Colin Edwards", "colin@recursivepenguin.com", "@DDRBoxman")
	addPerson("Colin Kennedy", "moshen.colin@gmail.com", "@moshen")
	addPerson("Conrad Irwin", "conrad.irwin@gmail.com", "@ConradIrwin")
	addPerson("Conrad Meyer", "cemeyer@cs.washington.edu", "@cemeyer")
	addPerson("Corey Thomasson", "cthom.lists@gmail.com", "@cthom06")
	addPerson("Cosmos Nicolaou", "cnicolaou@grailbio.com")
	addPerson("Craig Peterson", "cpeterson@stackoverflow.com")
	addPerson("Cristian Staretu", "unclejacksons@gmail.com", "@unclejack")
	addPerson("Cuihtlauac ALVARADO", "cuihtlauac.alvarado@orange.com", "@cuihtlauac")
	addPerson("Cyrill Schumacher", "cyrill@schumacher.fm", "@SchumacherFM")
	addPerson("Daker Fernandes Pinheiro", "daker.fernandes.pinheiro@intel.com", "@dakerfp")
	addPerson("Damian Gryski", "damian@gryski.com", "@dgryski")
	addPerson("Damian Gryski", "dgryski@gmail.com", "@dgryski")
	addPerson("Damien Lespiau", "damien.lespiau@gmail.com")
	addPerson("Damien Lespiau", "damien.lespiau@intel.com", "@dlespiau")
	addPerson("Damien Neil", "dneil@google.com")
	addPerson("Damien Neil", "dneil@google.com", "@neild")
	addPerson("Dan Adkins", "dadkins@gmail.com")
	addPerson("Dan Barry", "dan@bakineggs.com")
	addPerson("Dan Caddigan", "goldcaddy77@gmail.com", "@goldcaddy77")
	addPerson("Dan Callahan", "dan.callahan@gmail.com", "@callahad")
	addPerson("Dan Ertman", "dtertman@gmail.com")
	addPerson("Dan Goldsmith", "dan@d2g.org.uk")
	addPerson("Dan Harrington", "harringtond@google.com")
	addPerson("Dan Jacques", "dnj@google.com")
	addPerson("Dan Peterson", "dpiddy@gmail.com")
	addPerson("Dan Peterson", "dpiddy@gmail.com", "@danp")
	addPerson("Dan Sinclair", "dan.sinclair@gmail.com", "@dj2")
	addPerson("Dana Hoffman", "danahoffman@google.com")
	addPerson("Daniel Fleischman", "danielfleischman@gmail.com", "@danielf")
	addPerson("Daniel Johansson", "dajo2002@gmail.com", "@dajoo75")
	addPerson("Daniel Kerwin", "d.kerwin@gini.net", "@dkerwin")
	addPerson("Daniel Krech", "eikeon@eikeon.com", "@eikeon")
	addPerson("Daniel Martí", "mvdan@mvdan.cc", "@mvdan")
	addPerson("Daniel Morsing", "daniel.morsing@gmail.com")
	addPerson("Daniel Morsing", "daniel.morsing@gmail.com", "@DanielMorsing")
	addPerson("Daniel Ortiz Pereira da Silva", "daniel.particular@gmail.com", "@dopsilva")
	addPerson("Daniel Skinner", "daniel@dasa.cc")
	addPerson("Daniel Skinner", "daniel@dasa.cc", "@dskinner")
	addPerson("Daniel Speichert", "daniel@speichert.pl", "@DSpeichert")
	addPerson("Daniel Theophanes", "kardianos@gmail.com", "@kardianos")
	addPerson("Daniel Upton", "daniel@floppy.co", "@boxofrad")
	addPerson("Daniel Wagner-Hall", "dawagner@gmail.com")
	addPerson("Daniel, Dao Quang Minh", "dqminh89@gmail.com")
	addPerson("Danny Wyllie", "wylliedanny@gmail.com")
	addPerson("Danny Yoo", "dannyyoo@google.com")
	addPerson("Darren Elwood", "darren@textnode.com", "@textnode")
	addPerson("Datong Sun", "dndx@idndx.com", "@dndx")
	addPerson("Dave Borowitz", "dborowitz@google.com", "@dborowitz")
	addPerson("Dave Cheney", "dave@cheney.net", "@davecheney")
	addPerson("Dave Day", "djd@golang.org", "@okdave")
	addPerson("Dave MacFarlane", "driusan@gmail.com")
	addPerson("David Anderson", "danderson@google.com", "@danderson")
	addPerson("David Barnett", "dbarnett@google.com", "@dbarnett")
	addPerson("David Bartley", "bartle@stripe.com")
	addPerson("David Benjamin", "davidben@google.com", "@davidben")
	addPerson("David Benque", "dbenque@gmail.com")
	addPerson("David Brophy", "dave@brophy.uk", "@dave")
	addPerson("David Bürgin", "676c7473@gmail.com", "@glts")
	addPerson("David Calavera", "david.calavera@gmail.com", "@calavera")
	addPerson("David Chase", "drchase@google.com", "@dr2chase")
	addPerson("David Crawshaw", "crawshaw@golang.org", "@crawshaw")
	addPerson("David Deng", "daviddengcn@gmail.com")
	addPerson("David Forsythe", "dforsythe@gmail.com", "@dforsyth")
	addPerson("David G. Andersen", "dave.andersen@gmail.com", "@dave-andersen")
	addPerson("David Glasser", "glasser@meteor.com", "@glasser")
	addPerson("David Howden", "dhowden@gmail.com")
	addPerson("David Hubbard", "dsp@google.com")
	addPerson("David Jakob Fritz", "david.jakob.fritz@gmail.com", "@djfritz")
	addPerson("David Lazar", "lazard@golang.org", "@davidlazar")
	addPerson("David Leon Gil", "coruus@gmail.com", "@coruus")
	addPerson("David NewHamlet", "david@newhamlet.com", "@wheelcomplex")
	addPerson("David Presotto", "presotto@gmail.com", "@presotto")
	addPerson("David R. Jenni", "david.r.jenni@gmail.com", "@davidrjenni")
	addPerson("David Sansome", "me@davidsansome.com")
	addPerson("David Stainton", "dstainton415@gmail.com", "@david415")
	addPerson("David Symonds", "dsymonds@golang.org", "@dsymonds")
	addPerson("David Thomas", "davidthomas426@gmail.com", "@davidthomas426")
	addPerson("David Titarenco", "david.titarenco@gmail.com", "@dvx")
	addPerson("David Volquartz Lebech", "david@lebech.info")
	addPerson("David du Colombier", "0intro@gmail.com")
	addPerson("David du Colombier", "0intro@gmail.com", "@0intro")
	addPerson("Davies Liu", "davies.liu@gmail.com", "@davies")
	addPerson("Ddo", "joeddo89@gmail.com")
	addPerson("Dean Prichard", "dean.prichard@gmail.com", "@zard49")
	addPerson("Deepak Jois", "deepak.jois@gmail.com", "@deepakjois")
	addPerson("Denis Bernard", "db047h@gmail.com", "@db47h")
	addPerson("Denis Nagorny", "denis.nagorny@intel.com", "@dvnagorny")
	addPerson("Denys Honsiorovskyi", "honsiorovskyi@gmail.com", "@honsiorovskyi")
	addPerson("Derek Buitenhuis", "derek.buitenhuis@gmail.com", "@dwbuiten")
	addPerson("Derek Che", "drc@yahoo-inc.com")
	addPerson("Derek McGowan", "derek@mcgstyle.net")
	addPerson("Derek Parker", "parkerderek86@gmail.com", "@derekparker")
	addPerson("Derek Shockey", "derek.shockey@gmail.com", "@derelk")
	addPerson("Devon H. O'Dell", "devon.odell@gmail.com", "@dhobsd")
	addPerson("Dhaivat Pandit", "dhaivatpandit@gmail.com", "@ceocoder")
	addPerson("Dhananjay Nakrani", "dhananjayn@google.com")
	addPerson("Dhananjay Nakrani", "dhananjaynakrani@gmail.com", "@dhananjay92")
	addPerson("Dhiru Kholia", "dhiru.kholia@gmail.com", "@kholia")
	addPerson("Didier Spezia", "didier.06@gmail.com", "@dspezia")
	addPerson("Dieter Plaetinck", "dieter@raintank.io")
	addPerson("Dimitri Tcaciuc", "dtcaciuc@gmail.com", "@dtcaciuc")
	addPerson("Diogo Pinela", "diogoid7400@gmail.com")
	addPerson("Dirk Gadsden", "dirk@esherido.com", "@dirk")
	addPerson("Diwaker Gupta", "diwakergupta@gmail.com", "@diwakergupta")
	addPerson("Dmitri Popov", "operator@cv.dp-net.com", "@pin")
	addPerson("Dmitri Shuralyov", "shurcool@gmail.com", "@shurcooL")
	addPerson("Dmitriy Dudkin", "dudkin.dmitriy@gmail.com", "@tmwh")
	addPerson("Dmitry Chestnykh", "dchest@gmail.com", "@dchest")
	addPerson("Dmitry Pokidov", "dooman87@gmail.com")
	addPerson("Dmitry Savintsev", "dsavints@gmail.com", "@dmitris")
	addPerson("Dmitry Vyukov", "dvyukov@google.com", "@dvyukov")
	addPerson("Dominik Honnef", "dominik@honnef.co", "@dominikh")
	addPerson("Dominik Vogt", "vogt@linux.vnet.ibm.com", "@vogtd")
	addPerson("Donald Huang", "don.hcd@gmail.com")
	addPerson("Donovan Hide", "donovanhide@gmail.com", "@donovanhide")
	addPerson("Dragoslav Mitrinovic", "fdm224@motorola.com")
	addPerson("Drew Hintz", "adhintz@google.com", "@adhintz")
	addPerson("Duncan Holm", "mail@frou.org", "@frou")
	addPerson("Dustin Carlino", "dcarlino@google.com")
	addPerson("Dustin Shields-Cloues", "dcloues@gmail.com", "@dcloues")
	addPerson("Dylan Carney", "dcarney@gmail.com")
	addPerson("Eddie Ringle", "eddie@ringle.io")
	addPerson("Eden Li", "eden.li@gmail.com", "@eden")
	addPerson("Edward Muller", "edwardam@interlix.com", "@freeformz")
	addPerson("Egon Elbre", "egonelbre@gmail.com", "@egonelbre")
	addPerson("Ehren Kret", "ehren.kret@gmail.com", "@eakret")
	addPerson("Eitan Adler", "lists@eitanadler.com", "@grimreaper")
	addPerson("Eivind Uggedal", "eivind@uggedal.com", "@uggedal")
	addPerson("Elias Naur", "elias.naur@gmail.com", "@eliasnaur")
	addPerson("Elliot Morrison-Reed", "elliotmr@gmail.com", "@elliotmr")
	addPerson("Emanuele Iannone", "emanuele@fondani.it")
	addPerson("Emil Hessman", "emil@hessman.se", "@ceh")
	addPerson("Emmanuel Odeke", "emm.odeke@gmail.com", "@odeke-em")
	addPerson("Emmanuel Odeke", "odeke@ualberta.ca")
	addPerson("Eoghan Sherry", "ejsherry@gmail.com", "@ejsherry")
	addPerson("Eric Chiang", "eric.chiang.m@gmail.com", "@ericchiang")
	addPerson("Eric Clark", "zerohp@gmail.com", "@eclark")
	addPerson("Eric Engestrom", "eric@engestrom.ch", "@1ace")
	addPerson("Eric Garrido", "ekg@google.com", "@minusnine")
	addPerson("Eric Koleda", "ekoleda+devrel@google.com")
	addPerson("Eric Lagergren", "ericscottlagergren@gmail.com", "@ericlagergren")
	addPerson("Eric Milliken", "emilliken@gmail.com", "@emilliken")
	addPerson("Eric Roshan-Eisner", "eric.d.eisner@gmail.com", "@eisner")
	addPerson("Erik Aigner", "aigner.erik@gmail.com", "@eaigner")
	addPerson("Erik Dubbelboer", "erik@dubbelboer.com", "@erikdubbelboer")
	addPerson("Erik St. Martin", "alakriti@gmail.com", "@erikstmartin")
	addPerson("Erik Staab", "estaab@google.com", "@erikus")
	addPerson("Erik Westrup", "erik.westrup@gmail.com", "@erikw")
	addPerson("Ernest Chiang", "ernest_chiang@htc.com")
	addPerson("Esko Luontola", "esko.luontola@gmail.com", "@orfjackal")
	addPerson("Etai Lev Ran", "etail@il.ibm.com")
	addPerson("Ethan Burns", "eaburns@google.com")
	addPerson("Ethan Miller", "eamiller@us.ibm.com", "@millere")
	addPerson("Euan Kemp", "euank@euank.com", "@euank")
	addPerson("Evan Broder", "evan@stripe.com", "@evan-stripe")
	addPerson("Evan Brown", "evanbrown@google.com")
	addPerson("Evan Brown", "evanbrown@google.com", "@evandbrown")
	addPerson("Evan Kroske", "evankroske@google.com", "@evankroske")
	addPerson("Evan Martin", "evan.martin@gmail.com", "@evmar")
	addPerson("Evan Phoenix", "evan@phx.io", "@evanphx")
	addPerson("Evan Shaw", "chickencha@gmail.com")
	addPerson("Evan Shaw", "edsrzf@gmail.com", "@edsrzf")
	addPerson("Evgeniy Polyakov", "zbr@ioremap.net")
	addPerson("Evgeniy Polyakov", "zbr@ioremap.net", "@bioothod")
	addPerson("Ewan Chou", "coocood@gmail.com", "@coocood")
	addPerson("Eyal Posener", "posener@gmail.com")
	addPerson("Fab>rizio (Misto) Milo", "mistobaan@gmail.com", "@Mistobaan")
	addPerson("Fabian Wickborn", "fabian@wickborn.net", "@fawick")
	addPerson("Fabian", "fabian@youremail.eu")
	addPerson("Faiyaz Ahmed", "ahmedf@vmware.com", "@fdawg4l")
	addPerson("Fan Hongjian", "fan.howard@gmail.com", "@fango")
	addPerson("Fan Jiang", "fan.torchz@gmail.com")
	addPerson("Fangming.Fang", "fangming.fang@arm.com", "@zorrorffm")
	addPerson("Fatih Arslan", "fatih@arslan.io", "@fatih")
	addPerson("Fazal Majid", "majid@apsalar.com")
	addPerson("Fazlul Shahriar", "fshahriar@gmail.com", "@fhs")
	addPerson("Federico Simoncelli", "fsimonce@redhat.com", "@simon3z")
	addPerson("Fedor Indutny", "fedor@indutny.com", "@indutny")
	addPerson("Filip Gruszczyński", "gruszczy@gmail.com", "@gruszczy")
	addPerson("Filippo Valsorda", "hi@filippo.io", "@FiloSottile")
	addPerson("Firmansyah Adiputra", "frm.adiputra@gmail.com", "@frm-adiputra")
	addPerson("Florian Uekermann", "florian@uekermann.me", "@MaVo159")
	addPerson("Florian Weimer", "fw@deneb.enyo.de", "@fweimer")
	addPerson("Florin Patan", "florinpatan@gmail.com", "@dlsniper")
	addPerson("Ford Hurley", "ford.hurley@gmail.com", "@fordhurley")
	addPerson("Francesc Campoy", "campoy@golang.org", "campoy@google.com", "@campoy")
	addPerson("Francisco Claude", "fclaude@recoded.cl", "@fclaude")
	addPerson("Francisco Souza", "franciscossouza@gmail.com", "@fsouza")
	addPerson("Frank Rehwinkel", "frankrehwinkel@gmail.com")
	addPerson("Frank Schroeder", "frank.schroeder@gmail.com")
	addPerson("Frederick Kelly Mayle III", "frederickmayle@gmail.com", "@fkm3")
	addPerson("Fredrik Enestad", "fredrik.enestad@soundtrackyourbrand.com", "@fredr")
	addPerson("Fredrik Forsmo", "fredrik.forsmo@gmail.com", "@frozzare")
	addPerson("Frits van Bommel", "fvbommel@gmail.com", "@fvbommel")
	addPerson("Fumitoshi Ukai", "ukai@google.com", "@ukai")
	addPerson("Gabriel Aszalos", "gabriel.aszalos@gmail.com", "@gbbr")
	addPerson("Gabriel Russell", "gabriel.russell@gmail.com", "@wiccatech")
	addPerson("Gareth Paul Jones", "gpj@foursquare.com", "@garethpaul")
	addPerson("Gary Burd", "gary@beagledreams.com", "@garyburd")
	addPerson("Gary Elliott", "garyelliott@google.com")
	addPerson("Gaurish Sharma", "contact@gaurishsharma.com", "@gaurish")
	addPerson("Gautham Thambidorai", "gautham.dorai@gmail.com", "@gauthamt")
	addPerson("Geert-Johan Riemer", "gjr19912@gmail.com")
	addPerson("Georg Reinke", "guelfey@gmail.com", "@guelfey")
	addPerson("George Gkirtsou", "ggirtsou@gmail.com", "@ggirtsou")
	addPerson("George Shammas", "george@shamm.as", "@georgyo")
	addPerson("Gerasimos Dimitriadis", "gedimitr@gmail.com", "@gedimitr")
	addPerson("Giovanni Bajo", "rasky@develer.com", "@rasky")
	addPerson("Giulio Iotti", "dullgiulio@gmail.com", "@dullgiulio")
	addPerson("Giuseppe Valente", "gvalente@arista.com")
	addPerson("Gleb Smirnoff", "glebius@netflix.com")
	addPerson("Gleb Stepanov", "glebstepanov1992@gmail.com", "@stgleb")
	addPerson("Glenn Brown", "glennb@google.com")
	addPerson("Glenn Lewis", "gmlewis@google.com", "@gmlewis")
	addPerson("Gordon Klaus", "gordon.klaus@gmail.com", "@gordonklaus")
	addPerson("Graham Miller", "graham.miller@gmail.com", "@laslowh")
	addPerson("Greg Ward", "greg@gerg.ca", "@gward")
	addPerson("Gregory Haskins", "gregory.haskins@gmail.com")
	addPerson("Gregory Man", "man.gregory@gmail.com")
	addPerson("Guillaume J. Charmes", "guillaume@charmes.net", "@creack")
	addPerson("Guillaume Leroi", "leroi.g@gmail.com")
	addPerson("Guillermo López-Anglada", "guillermo.lopez@outlook.com", "@guillermooo")
	addPerson("Guobiao Mei", "meiguobiao@gmail.com", "@guobiao")
	addPerson("Gurpartap Singh", "hi@gurpartap.com")
	addPerson("Gustav Paul", "gustav.paul@gmail.com", "@gpaul")
	addPerson("Gustav Westling", "gustav@westling.xyz", "@zegl")
	addPerson("Gustavo Niemeyer", "gustavo@niemeyer.net", "n13m3y3r@gmail.com", "@niemeyer")
	addPerson("Gyu-Ho Lee", "gyuhox@gmail.com", "@gyuho")
	addPerson("H. İbrahim Güngör", "igungor@gmail.com", "@igungor")
	addPerson("Hajime Hoshi", "hajimehoshi@gmail.com", "@hajimehoshi")
	addPerson("Han-Wen Nienhuys", "hanwen@google.com", "@hanwen")
	addPerson("Hana Kim", "hyangah@gmail.com", "@hyangah")
	addPerson("Hari haran", "hariharan.uno@gmail.com", "@hariharan-uno")
	addPerson("Hariharan Srinath", "srinathh@gmail.com", "@srinathh")
	addPerson("Harry Moreno", "morenoh149@gmail.com", "@morenoh149")
	addPerson("Harshavardhana", "hrshvardhana@gmail.com", "@harshavardhana")
	addPerson("Hauke Löffler", "hloeffler@users.noreply.github.com", "@hloeffler")
	addPerson("Hector Chu", "hectorchu@gmail.com", "@hectorchu")
	addPerson("Hector Jusforgues", "hector.jusforgues@gmail.com")
	addPerson("Hector Martin Cantero", "hector@marcansoft.com", "@marcan")
	addPerson("Hector Rivas Gandara", "keymon@gmail.com")
	addPerson("Henning Schmiedehausen", "henning@schmiedehausen.org", "@hgschmie")
	addPerson("Henrik Hodne", "henrik@hodne.io", "@henrikhodne")
	addPerson("Henrique Vicente", "henriquevicente@gmail.com")
	addPerson("Herbert Georg Fischer", "herbert.fischer@gmail.com", "@hgfischer")
	addPerson("Herbie Ong", "herbie@google.com", "@cybrcodr")
	addPerson("Heschi Kreinick", "heschi@google.com", "@heschik")
	addPerson("Hiroaki Nakamura", "hnakamur@gmail.com")
	addPerson("Hironao OTSUBO", "motemen@gmail.com", "@motemen")
	addPerson("Hiroshi Ioka", "hirochachacha@gmail.com", "@hirochachacha")
	addPerson("Hitoshi Mitake", "mitake.hitoshi@gmail.com", "@mitake")
	addPerson("Hong Ruiqi", "hongruiqi@gmail.com", "@hongruiqi")
	addPerson("Hsin Tsao", "tsao@google.com")
	addPerson("Hsin Tsao", "tsao@google.com", "@lazyhackeratwork")
	addPerson("HuKeping", "hukeping@huawei.com", "@HuKeping")
	addPerson("Hugues Bruant", "hugues.bruant@gmail.com", "@huguesb")
	addPerson("Hyang-Ah Hana Kim", "hyangah@gmail.com", "hakim@google.com", "@hyangah")
	addPerson("Håvard Haugen", "havard.haugen@gmail.com", "@osocurioso")
	addPerson("INADA Naoki", "songofacandy@gmail.com", "@methane")
	addPerson("Ian Gudger", "ian@loosescre.ws")
	addPerson("Ian Gudger", "igudger@google.com", "@iangudger")
	addPerson("Ian Lance Taylor", "iant@golang.org", "@ianlancetaylor")
	addPerson("Ibrahim AshShohail", "ibra.sho@gmail.com", "@ibrasho")
	addPerson("Idora Shinatose", "idora.shinatose@gmail.com", "@idora")
	addPerson("Igor Bernstein", "igorbernstein@google.com")
	addPerson("Igor Dolzhikov", "bluesriverz@gmail.com", "@takama")
	addPerson("Ilia Filippov", "ilia.filippov@intel.com")
	addPerson("Ilya Tocar", "ilya.tocar@intel.com", "@TocarIP")
	addPerson("Ingo Krabbe", "ikrabbe.ask@gmail.com", "@ikrabbe")
	addPerson("Ingo Oeser", "nightlyone@googlemail.com", "@nightlyone")
	addPerson("Ivan Babrou", "ivan@cloudflare.com", "@bobrik")
	addPerson("Ivan Krasin", "krasin@golang.org", "@krasin2")
	addPerson("Ivan Kruglov", "ivan.kruglov@yahoo.com")
	addPerson("Ivan Ukhov", "ivan.ukhov@gmail.com", "@IvanUkhov")
	addPerson("JP Sugarbroad", "jpsugar@google.com", "@taralx")
	addPerson("JT Olds", "hello@jtolds.com", "@jtolds")
	addPerson("Jaana Burcu Dogan", "jbd@google.com", "jbd@golang.org", "@rakyll")
	addPerson("Jack Christensen", "jack@jackchristensen.com")
	addPerson("Jack Lindamood", "jlindamo@justin.tv", "@cep21")
	addPerson("Jackson Owens", "jackson_owens@alumni.brown.edu")
	addPerson("Jacob H. Haven", "jacob@cloudflare.com")
	addPerson("Jacob H. Haven", "jacob@jhaven.me", "@jacobhaven")
	addPerson("Jacob Hoffman-Andrews", "github@hoffman-andrews.com", "@jsha")
	addPerson("Jacob Marble", "jacobmarble@google.com")
	addPerson("Jae Kwon", "jae@tendermint.com", "@jaekwon")
	addPerson("Jakob Borg", "jakob@nym.se", "@calmh")
	addPerson("Jakub Ryszard Czarnowicz", "j.czarnowicz@gmail.com", "@Naranim")
	addPerson("Jakub Čajka", "jcajka@redhat.com", "@jcajka")
	addPerson("James Bardin", "j.bardin@gmail.com", "@jbardin")
	addPerson("James Chacon", "jchacon@google.com")
	addPerson("James Clarke", "jrtc27@jrtc27.com", "@jrtc27")
	addPerson("James Fysh", "james.fysh@gmail.com", "@JamesFysh")
	addPerson("James Gray", "james@james4k.com", "@james4k")
	addPerson("James Hartig", "fastest963@gmail.com", "@fastest963")
	addPerson("James Munnelly", "james@munnelly.eu")
	addPerson("James Myers", "jfmyers9@gmail.com", "@jfmyers9")
	addPerson("James Neve", "jamesoneve@gmail.com", "@jamesneve")
	addPerson("James Robinson", "jamesr@google.com", "@jamesr")
	addPerson("James Schofield", "james@shoeboxapp.com", "@jamesshoebox")
	addPerson("James Smith", "jrs1995@icloud.com", "@jimmysmith95")
	addPerson("James Sweet", "james.sweet88@googlemail.com", "@Omegaice")
	addPerson("James Toy", "nil@opensesame.st", "@jamestoy")
	addPerson("James Tucker", "raggi@google.com", "@raggi")
	addPerson("James Whitehead", "jnwhiteh@gmail.com", "@jnwhiteh")
	addPerson("Jamie Beverly", "jamie.r.beverly@gmail.com", "@jbeverly")
	addPerson("Jamie Stackhouse", "contin673@gmail.com", "@itsjamie")
	addPerson("Jamie Wilkinson", "jaq@spacepants.org", "@jaqx0r")
	addPerson("Jamil Djadala", "djadala@gmail.com", "@djadala")
	addPerson("Jan Berktold", "jan@berktold.co")
	addPerson("Jan H. Hosang", "jan.hosang@gmail.com", "@hosang")
	addPerson("Jan Kratochvil", "jan.kratochvil@redhat.com", "@jankratochvil")
	addPerson("Jan Mercl", "0xjnml@gmail.com", "@cznic")
	addPerson("Jan Mercl", "befelemepeseveze@gmail.com", "@bflm")
	addPerson("Jan Ziak", "0xe2.0x9a.0x9b@gmail.com", "@atomsymbol")
	addPerson("Janne Snabb", "snabb@epipe.com", "@snabb")
	addPerson("Jason Barnett", "jason.w.barnett@gmail.com", "@jasonwbarnett")
	addPerson("Jason Buberel", "jbuberel@google.com", "jason@buberel.org", "@jbuberel")
	addPerson("Jason Chu", "jasonchujc@gmail.com", "@1lann")
	addPerson("Jason Cwik", "jason@cwik.org")
	addPerson("Jason Del Ponte", "delpontej@gmail.com", "@jasdel")
	addPerson("Jason E. Aten", "j.e.aten@gmail.com")
	addPerson("Jason Hall", "imjasonh@gmail.com")
	addPerson("Jason McVetta", "jason.mcvetta@gmail.com", "@jmcvetta")
	addPerson("Jason Smale", "jsmale@zendesk.com")
	addPerson("Jason Travis", "infomaniac7@gmail.com", "@corburn")
	addPerson("Jay Conrod", "jayconrod@google.com", "@jayconrod")
	addPerson("Jay Satiro", "raysatiro@yahoo.com")
	addPerson("Jay Weisskopf", "jay@jayschwa.net", "@jayschwa")
	addPerson("Jean de Klerk", "jadekler@gmail.com")
	addPerson("Jean-Marc Eurin", "jmeurin@google.com", "@jmeurin")
	addPerson("Jean-Nicolas Moal", "jn.moal@gmail.com", "@jnmoal")
	addPerson("Jed Denlea", "jed@fastly.com", "@jeddenlea")
	addPerson("Jeff (Zhefu) Jiang", "jeffjiang@google.com")
	addPerson("Jeff Craig", "jeffcraig@google.com", "@foxxtrot")
	addPerson("Jeff Hodges", "jeff@somethingsimilar.com", "@jmhodges")
	addPerson("Jeff Johnson", "jrjohnson@google.com", "@johnsonj")
	addPerson("Jeff R. Allen", "jra@nella.org", "@jeffallen")
	addPerson("Jeff Sickel", "jas@corpus-callosum.com", "@vat9")
	addPerson("Jeff Wendling", "jeff@spacemonkey.com", "@zeebo")
	addPerson("Jens Frederich", "jfrederich@gmail.com", "@frederich")
	addPerson("Jeremiah Harmsen", "jeremiah@google.com", "@jharmsen")
	addPerson("Jeremy Jackins", "jeremyjackins@gmail.com", "@jnjackins")
	addPerson("Jeremy Schlatter", "jeremy.schlatter@gmail.com", "@jeremyschlatter")
	addPerson("Jeroen Bobbeldijk", "jerbob92@gmail.com", "@jerbob92")
	addPerson("Jess Frazelle", "acidburn@google.com", "@jessfraz")
	addPerson("Jess Frazelle", "me@jessfraz.com", "@jessfraz")
	addPerson("Jesse Szwedko", "jesse.szwedko@gmail.com", "@jszwedko")
	addPerson("Jian Zhen", "zhenjl@gmail.com")
	addPerson("Jianing Yu", "jnyu@google.com")
	addPerson("Jihyun Yu", "yjh0502@gmail.com", "@yjh0502")
	addPerson("Jim Cote", "jfcote87@gmail.com", "@jfcote87")
	addPerson("Jim Kingdon", "jim@bolt.me", "@jkingdon")
	addPerson("Jim McGrath", "jimmc2@gmail.com", "@mcgoo")
	addPerson("Jimmy Zelinskie", "jimmyzelinskie@gmail.com", "@jzelinskie")
	addPerson("Jin-wook Jeong", "jeweljar@hanmail.net", "@jeweljar")
	addPerson("Jingcheng Zhang", "diogin@gmail.com", "@diogin")
	addPerson("Jingguo Yao", "yaojingguo@gmail.com", "@yaojingguo")
	addPerson("Jiong Du", "londevil@gmail.com", "@lodevil")
	addPerson("Jirka Daněk", "dnk@mail.muni.cz", "@jirkadanek")
	addPerson("Joakim Sernbrant", "serbaut@gmail.com", "@serbaut")
	addPerson("Joe Farrell", "joe2farrell@gmail.com", "@joe2far")
	addPerson("Joe Harrison", "joehazzers@gmail.com", "@sigwinch28")
	addPerson("Joe Henke", "joed.henke@gmail.com", "@jdhenke")
	addPerson("Joe Poirier", "jdpoirier@gmail.com", "@jpoirier")
	addPerson("Joe Shaw", "joe@joeshaw.org")
	addPerson("Joe Shaw", "joe@joeshaw.org", "@joeshaw")
	addPerson("Joe Sylve", "joe.sylve@gmail.com", "@jtsylve")
	addPerson("Joe Tsai", "joetsai@digital-static.net", "joetsai@google.com", "thebrokentoaster@gmail.com", "@dsnet")
	addPerson("Joel Sing", "joel@sing.id.au", "jsing@google.com", "@4a6f656c")
	addPerson("Johan Brandhorst", "johan.brandhorst@gmail.com", "@johanbrandhorst")
	addPerson("Johan Euphrosine", "proppy@google.com", "@proppy")
	addPerson("Johan Sageryd", "j@1616.se", "@jsageryd")
	addPerson("Johan Schuijt-Li", "johan@300.nl")
	addPerson("John Asmuth", "jasmuth@gmail.com", "jasmuth@google.com", "@skelterjohn")
	addPerson("John Beisley", "huin@google.com", "@huin-google")
	addPerson("John Dethridge", "jcd@golang.org", "@jcd2")
	addPerson("John Howard Palevich", "jack.palevich@gmail.com", "@jackpal")
	addPerson("John Jeffery", "jjeffery@sp.com.au", "@jjeffery")
	addPerson("John Potocny", "johnp@vividcortex.com", "@potocnyj")
	addPerson("John Schnake", "schnake.john@gmail.com", "@johnSchnake")
	addPerson("John ShaggyTwoDope Jenkins", "twodopeshaggy@gmail.com", "@shaggytwodope")
	addPerson("John Shahid", "jvshahid@gmail.com", "@jvshahid")
	addPerson("John Starks", "jostarks@microsoft.com")
	addPerson("John Tuley", "john@tuley.org", "@jmtuley")
	addPerson("Jon Chen", "jchen@justin.tv", "@bsdlp")
	addPerson("Jonathan Amsterdam", "jba@google.com", "@jba")
	addPerson("Jonathan Anderson", "jonathan.anderson@mun.ca")
	addPerson("Jonathan Boulle", "jonathanboulle@gmail.com", "@jonboulle")
	addPerson("Jonathan Doklovic", "doklovic@atlassian.com")
	addPerson("Jonathan Feinberg", "feinberg@google.com", "@google-feinberg")
	addPerson("Jonathan Hseu", "jhseu@google.com", "@jhseu")
	addPerson("Jonathan Mark", "jhmark@xenops.com", "@jhmark")
	addPerson("Jonathan Nieder", "jrn@google.com", "@jrn")
	addPerson("Jonathan Pittman", "jmpittman@google.com", "@jonathanpittman")
	addPerson("Jonathan Rudenberg", "jonathan@titanous.com", "@titanous")
	addPerson("Jonathan Wills", "runningwild@gmail.com", "@runningwild")
	addPerson("Jongmin Kim", "atomaths@gmail.com", "@atomaths")
	addPerson("Joonas Kuorilehto", "joneskoo@derbian.fi", "@joneskoo")
	addPerson("Joop Kiefte", "joop@kiefte.net", "@LaPingvino")
	addPerson("Jordan Lewis", "jordanthelewis@gmail.com", "@jordanlewis")
	addPerson("Jordan Liggitt", "jliggitt@redhat.com")
	addPerson("Jos Visser", "josv@google.com", "@gosbisser")
	addPerson("Jose Luis Vázquez González", "josvazg@gmail.com", "@josvazg")
	addPerson("Joseph Holsten", "joseph@josephholsten.com", "@josephholsten")
	addPerson("Joseph Poirier", "jdpoirier@gmail.com")
	addPerson("Joseph Richey", "joerichey@google.com", "@josephlr")
	addPerson("Joseph Spurrier", "code@josephspurrier.com")
	addPerson("Josh Bleecher Snyder", "josharian@gmail.com", "@josharian")
	addPerson("Josh Chorlton", "jchorlton@gmail.com", "@jchorl")
	addPerson("Josh Deprez", "josh.deprez@gmail.com", "@DrJosh9000")
	addPerson("Josh Goebel", "dreamer3@gmail.com", "@yyyc514")
	addPerson("Josh Hoak", "jhoak@google.com", "@Kashomon")
	addPerson("Joshua Boelter", "joshua.boelter@intel.com")
	addPerson("Joshua T Corbin", "joshua@uber.com")
	addPerson("Josselin Costanzi", "josselin@costanzi.fr")
	addPerson("Jostein Stuhaug", "js@solidsystem.no")
	addPerson("Joël Stemmer", "jstemmer@google.com", "@jstemmer")
	addPerson("Joël Stemmer", "stemmertech@gmail.com", "@jstemmer")
	addPerson("JuciÊ Dias Andrade", "ojucie@gmail.com")
	addPerson("Jukka-Pekka Kekkonen", "karatepekka@gmail.com", "@madari")
	addPerson("Julia Hansbrough", "flowerhack@google.com", "@flowerhack")
	addPerson("Julian Kornberger", "jk+github@digineo.de", "@corny")
	addPerson("Julian Phillips", "julian@quantumfyre.co.uk", "@qur")
	addPerson("Julien Schmidt", "google@julienschmidt.com", "@julienschmidt")
	addPerson("Jungho Ahn", "jhahn@google.com", "@jhahn21")
	addPerson("Jure Ham", "jure.ham@zemanta.com", "@hamaxx")
	addPerson("Justin Nuß", "nuss.justin@gmail.com", "@nussjustin")
	addPerson("Justyn Temme", "justyntemme@gmail.com", "@justyntemme")
	addPerson("KB Sriram", "kbsriram@google.com", "@kbsriram")
	addPerson("Kale Blankenship", "kale@lemnisys.com", "@vcabbage")
	addPerson("Kaleb Elwert", "kelwert@atlassian.com", "@belak")
	addPerson("Kamal Aboul-Hosn", "aboulhosn@google.com")
	addPerson("Kamal Aboul-Hosn", "kamal.aboulhosn@gmail.com")
	addPerson("Kamil Kisiel", "kamil@kamilkisiel.net", "@kisielk")
	addPerson("Kang Hu", "hukangustc@gmail.com", "@mkhu")
	addPerson("Karan Misra", "kidoman@gmail.com")
	addPerson("Kato Kazuyoshi", "kato.kazuyoshi@gmail.com", "@kzys")
	addPerson("Katrina Owen", "katrina.owen@gmail.com", "@kytrinyx")
	addPerson("Kaviraj", "kavirajkanagaraj@gmail.com", "@kavirajk")
	addPerson("Keegan Carruthers-Smith", "keegan.csmith@gmail.com", "@keegancsmith")
	addPerson("Kei Son", "hey.calmdown@gmail.com", "@heycalmdown")
	addPerson("Keiji Yoshida", "keijiyoshida.mail@gmail.com", "@keijiyoshida")
	addPerson("Keith Ball", "inflatablewoman@gmail.com")
	addPerson("Keith Randall", "khr@google.com", "khr@golang.org", "keithr@alum.mit.edu", "@randall77")
	addPerson("Keith Rarick", "kr@xph.us", "@kr")
	addPerson("Kelsey Hightower", "kelsey.hightower@gmail.com", "@kelseyhightower")
	addPerson("Ken Friedenbach", "kenliz@cruzio.com", "@Ken1JF")
	addPerson("Ken Rockot", "ken@oz.gs", "@krockot")
	addPerson("Ken Sedgwick", "ken@bonsai.com", "@ksedgwic")
	addPerson("Ken Thompson", "ken@golang.org", "@ken")
	addPerson("Kenji Kaneda", "kenji.kaneda@gmail.com", "@kkaneda")
	addPerson("Kenneth Shaw", "kenshaw@gmail.com", "@kenshaw")
	addPerson("Kenny Grant", "kennygrant@gmail.com", "@kennygrant")
	addPerson("Kevin Ballard", "kevin@sb.org", "@kballard")
	addPerson("Kevin Burke", "kev@inburke.com", "@kevinburke")
	addPerson("Kevin Kirsche", "kev.kirsche@gmail.com", "@kkirsche")
	addPerson("Kevin Klues", "klueska@gmail.com", "@klueska")
	addPerson("Kevin Malachowski", "chowski@google.com")
	addPerson("Kevin Vu", "kevin.m.vu@gmail.com", "@kvu787")
	addPerson("Kevin Wang", "kevin@kevinwang.com")
	addPerson("Khramov Anton", "anton@endocode.com")
	addPerson("Kim Shrier", "kshrier@racktopsystems.com", "@kim-racktop")
	addPerson("Kirill Korotaev", "kirillx@gmail.com")
	addPerson("Kirill Smelkov", "kirr@nexedi.com", "@navytux")
	addPerson("Kirklin McDonald", "kirklin.mcdonald@gmail.com", "@KirkMcDonald")
	addPerson("Klaus Post", "klauspost@gmail.com", "@klauspost")
	addPerson("Koala Yeung", "koalay@gmail.com")
	addPerson("Koichi Shiraishi", "zchee.io@gmail.com", "@zchee")
	addPerson("Koki Ide", "niconegoto@yahoo.co.jp", "@niconegoto")
	addPerson("Konstantin Shaposhnikov", "k.shaposhnikov@gmail.com", "@kostya-sh")
	addPerson("Kris Nova", "kris@nivenly.com", "@kris-nova")
	addPerson("Kris", "krousey@google.com")
	addPerson("Krish Munot", "krishmunot@gmail.com")
	addPerson("Kristopher Watts", "traetox@gmail.com", "@traetox")
	addPerson("Kun", "likunarmstrong@gmail.com", "@cnbuff410")
	addPerson("Kyle Consalus", "consalus@gmail.com", "@kcons")
	addPerson("Kyle Isom", "kyle@gokyle.net", "@kisom")
	addPerson("Kyle Jones", "kyle@kyledj.com")
	addPerson("Kyle Lemons", "kyle@kylelemons.net", "@kylelemons")
	addPerson("Kyrylo Silin", "silin@kyrylo.org", "@kyrylo")
	addPerson("L Campbell", "unpantsu@gmail.com", "@lye")
	addPerson("LE Manh Cuong", "cuong.manhle.vn@gmail.com", "@Gnouc")
	addPerson("Lai Jiangshan", "eag0628@gmail.com", "@laijs")
	addPerson("Larry Hosken", "lahosken@gmail.com", "@lahosken")
	addPerson("Lars Wiegman", "lars@namsral.com", "@namsral")
	addPerson("Larz Conwell", "larzconwell@gmail.com", "@larzconwell")
	addPerson("Laurie Clark-Michalek", "laurie@qubit.com", "@lclarkmichalek")
	addPerson("Lee Hinman", "hinman@gmail.com", "@hinman")
	addPerson("Lee Packham", "lpackham@gmail.com", "@leepa")
	addPerson("Leon Klingele", "git@leonklingele.de", "@leonklingele")
	addPerson("Lev Shamardin", "shamardin@gmail.com", "@abbot")
	addPerson("Lewin Bormann", "lbo@spheniscida.de")
	addPerson("Lewin Bormann", "lewin.bormann@gmail.com", "@dermesser")
	addPerson("Lion Yang", "lion@aosc.xyz", "@LionNatsu")
	addPerson("Lloyd Dewolf", "foolswisdom@gmail.com", "@lloydde")
	addPerson("Lorenzo Masini", "rugginoso@develer.com", "@rugginoso")
	addPerson("Lorenzo Stoakes", "lstoakes@gmail.com", "@lorenzo-stoakes")
	addPerson("Luan Santos", "cfcluan@gmail.com", "@luan")
	addPerson("Luca Greco", "luca.greco@alcacoop.it", "@rpl")
	addPerson("Lucas Bremgartner", "lucas.bremgartner@gmail.com", "@breml")
	addPerson("Lucas Clemente", "lclemente@google.com", "@lucas-clemente")
	addPerson("Lucas Garron", "lgarron@chromium.org", "*goog")
	addPerson("Lucien Stuker", "lucien.stuker@gmail.com", "@LStuker")
	addPerson("Lucio De Re", "lucio.dere@gmail.com", "@lootch")
	addPerson("Ludi Rehak", "ludi317@gmail.com", "@ludi317")
	addPerson("Luigi Riefolo", "luigi.riefolo@gmail.com", "@luigi-riefolo")
	addPerson("Luit van Drongelen", "luit@luit.it", "@Luit")
	addPerson("Luit van Drongelen", "luitvd@gmail.com", "@Luit")
	addPerson("Luka Zakrajšek", "tr00.g33k@gmail.com")
	addPerson("Lukasz Milewski", "lmmilewski@gmail.com", "lmilewski@google.com", "@LMMilewski")
	addPerson("Luke Curley", "qpingu@gmail.com", "@kixelated")
	addPerson("Luna Duclos", "luna.duclos@palmstonegames.com")
	addPerson("Lynn Boger", "laboger@linux.vnet.ibm.com", "@laboger")
	addPerson("Magnus Hiie", "magnus.hiie@gmail.com")
	addPerson("Maksym Trykur", "maksym.trykur@gmail.com", "@mak73kur")
	addPerson("Mal Curtis", "mal@mal.co.nz", "@snikch")
	addPerson("Manfred Touron", "m@42.am", "@moul")
	addPerson("Manu S Ajith", "neo@codingarena.in", "@manusajith")
	addPerson("Manuel FernandezaaZ", "sourvivor@gmail.com")
	addPerson("Marc Vandenbosch", "marc.vandenbosch@gmail.com")
	addPerson("Marc-Antoine Ruel", "maruel@chromium.org", "@maruel", "*goog")
	addPerson("Marcel Edmund Franke", "marcel.edmund.franke@gmail.com", "@donutloop")
	addPerson("Marcel Lanz", "marcel.lanz@n-1.ch")
	addPerson("Marcel van Lohuizen", "mpvl@golang.org", "@mpvl")
	addPerson("Marco Hennings", "marco.hennings@freiheit.com", "@mhennings")
	addPerson("Marco Peereboom", "marco@peereboom.us")
	addPerson("Marek Polacek", "polacek@redhat.com", "@mpolacek")
	addPerson("Marga Manterola", "marga@google.com", "@margamanterola")
	addPerson("Marin", "marin.basic02@gmail.com", "@MarinX")
	addPerson("Marius Kittler", "mariuskittler@gmx.de")
	addPerson("Marius Nuennerich", "mnu@google.com")
	addPerson("Mark Adams", "mark@markadams.me", "@mark-adams")
	addPerson("Mark Bucciarelli", "mkbucc@gmail.com", "@mbucc")
	addPerson("Mark Lee", "code0x9@gmail.com")
	addPerson("Mark Ryan", "mark.d.ryan@intel.com", "@markdryan")
	addPerson("Mark Severson", "miquella@gmail.com", "@miquella")
	addPerson("Mark Theunissen", "mark.theunissen@gmail.com", "@marktheunissen")
	addPerson("Mark Zavislak", "zavislak@google.com", "@zavislak")
	addPerson("Marko Juhani Silokunnas", "marko.silokunnas@gmail.com", "@marant")
	addPerson("Marko Tiikkaja", "marko@joh.to", "@johto")
	addPerson("Markus Sonderegger", "marraison@gmail.com", "@mars9")
	addPerson("Markus Zimmermann", "markus.zimmermann@nethead.at")
	addPerson("Markus Zimmermann", "zimmski@gmail.com", "@zimmski")
	addPerson("Martin Bertschler", "mbertschler@gmail.com", "@mbertschler")
	addPerson("Martin Garton", "garton@gmail.com", "@MartinGarton")
	addPerson("Martin Habbecke", "marhab@google.com")
	addPerson("Martin Hamrle", "martin.hamrle@gmail.com", "@mhamrle")
	addPerson("Martin Kreichgauer", "martinkr@google.com", "@kreichgauer")
	addPerson("Martin Lindhe", "martin.j.lindhe@gmail.com", "@martinlindhe")
	addPerson("Martin Möhrmann", "moehrmann@google.com", "martisch@uos.de", "@martisch")
	addPerson("Martin Olsen", "github.com@martinolsen.net", "@martinolsen")
	addPerson("Martin Olsson", "martin@minimum.se", "@mo")
	addPerson("Marvin Stenger", "marvin.stenger94@gmail.com")
	addPerson("Masa Sekimura", "sekimura@gmail.com")
	addPerson("Mateusz Czapliński", "czapkofan@gmail.com", "@akavel")
	addPerson("Mathias Hall-Andersen", "mathias@hall-andersen.dk")
	addPerson("Mathias Leppich", "mleppich@muhqu.de", "@muhqu")
	addPerson("MathiasB", "git@denbeke.be", "@DenBeke")
	addPerson("Mats Lidell", "mats.lidell@cag.se", "@matsl")
	addPerson("Matt Aimonetti", "mattaimonetti@gmail.com", "@mattetti")
	addPerson("Matt Blair", "me@matthewblair.net", "@mblair")
	addPerson("Matt Bostock", "matt@mattbostock.com", "@mattbostock")
	addPerson("Matt Drollette", "matt@drollette.com", "@MDrollette")
	addPerson("Matt DuVall", "matt@stripe.com")
	addPerson("Matt Harden", "matt.harden@gmail.com")
	addPerson("Matt Jibson", "matt.jibson@gmail.com", "@mjibson")
	addPerson("Matt Joiner", "anacrolix@gmail.com", "@anacrolix")
	addPerson("Matt Jones", "matt@mhjones.org")
	addPerson("Matt Keenan", "github@mattkeenan.net", "@mattkeenan")
	addPerson("Matt Layher", "mdlayher@gmail.com", "@mdlayher")
	addPerson("Matt Reiferson", "mreiferson@gmail.com", "@mreiferson")
	addPerson("Matt Robenolt", "matt@ydekproductions.com", "@mattrobenolt")
	addPerson("Matt T. Proud", "matt.proud@gmail.com", "@matttproud")
	addPerson("Matteo Croce", "matteo.croce@canonical.com")
	addPerson("Matthew Brennan", "matty.brennan@gmail.com", "@mattyb")
	addPerson("Matthew Cottingham", "mattcottingham@gmail.com", "@mattrco")
	addPerson("Matthew Dempsky", "mdempsky@google.com", "@mdempsky")
	addPerson("Matthew Denton", "mdenton@skyportsystems.com", "@mdentonSkyport")
	addPerson("Matthew Endsley", "mendsley@gmail.com")
	addPerson("Matthew Herrmann", "mherr@google.com")
	addPerson("Matthew Holt", "matthew.holt+git@gmail.com", "@mholt")
	addPerson("Matthew Horsnell", "matthew.horsnell@gmail.com", "@matt2909")
	addPerson("Matthieu Hauglustaine", "matt.hauglustaine@gmail.com", "@MattHauglustaine")
	addPerson("Matthieu Sarter", "matthieu.sarter.external@atos.net", "@MatthieuSarter")
	addPerson("Max Riveiro", "kavu13@gmail.com", "@kavu")
	addPerson("Maxime de Roucy", "maxime.deroucy@gmail.com", "@tchernomax")
	addPerson("Maxwell Krohn", "themax@gmail.com", "@maxtaco")
	addPerson("Meir Fischer", "meirfischer@gmail.com", "@meirf")
	addPerson("Meng Zhuo", "mengzhuo1203@gmail.com", "@mengzhuo")
	addPerson("Menghan Li", "menghanl@google.com")
	addPerson("Mhd Sulhan", "m.shulhan@gmail.com", "@shuLhan")
	addPerson("MiLk", "hello@emilienkenler.com", "@MiLk")
	addPerson("Michael Chaten", "mchaten@gmail.com", "@chaten")
	addPerson("Michael Darakananda", "pongad@gmail.com")
	addPerson("Michael Darakananda", "pongad@google.com")
	addPerson("Michael Elkins", "michael.elkins@gmail.com", "@sigpipe")
	addPerson("Michael Fraenkel", "michael.fraenkel@gmail.com", "@fraenkel")
	addPerson("Michael Gehring", "mg@ebfe.org", "@ebfe")
	addPerson("Michael Hoisie", "hoisie@gmail.com", "@hoisie")
	addPerson("Michael Hudson-Doyle", "michael.hudson@canonical.com", "@mwhudson")
	addPerson("Michael Kuryshev", "me@mk9.name")
	addPerson("Michael Käufl", "golang@c.michael-kaeufl.de", "@michael-k")
	addPerson("Michael Lewis", "mikelikespie@gmail.com", "@mikelikespie")
	addPerson("Michael MacInnis", "michael.p.macinnis@gmail.com", "@michaelmacinnis")
	addPerson("Michael Marineau", "michael.marineau@coreos.com", "mike@marineau.org", "@marineam")
	addPerson("Michael Matloob", "matloob@golang.org", "matloob@google.com", "@matloob")
	addPerson("Michael McConville", "momcconville@gmail.com")
	addPerson("Michael McGreevy", "mcgreevy@golang.org", "@mcgreevy")
	addPerson("Michael Munday", "mike.munday@ibm.com", "munday@ca.ibm.com", "@mundaym")
	addPerson("Michael Pearson", "mipearson@gmail.com", "@mipearson")
	addPerson("Michael Pratt", "mpratt@google.com", "@prattmic")
	addPerson("Michael Schaller", "michael@5challer.de", "@michael-schaller")
	addPerson("Michael Shields", "mshields@google.com", "@shields")
	addPerson("Michael Smith", "mikejsmitty@gmail.com")
	addPerson("Michael Spiegel", "michael.m.spiegel@gmail.com")
	addPerson("Michael Stapelberg", "stapelberg@google.com", "@stapelberg")
	addPerson("Michael Sterle-Contala", "mike.sterle@gmail.com")
	addPerson("Michael Teichgräber", "mteichgraeber@gmx.de", "@knieriem")
	addPerson("Michael Vetter", "g.bluehut@gmail.com", "@jubalh")
	addPerson("Michal Bohuslávek", "mbohuslavek@gmail.com", "@mibk")
	addPerson("Michal Cierniak", "cierniak@google.com", "@cierniak")
	addPerson("Michalis Kargakis", "michaliskargakis@gmail.com")
	addPerson("Michel Lespinasse", "walken@google.com", "@walken-google")
	addPerson("Miek Gieben", "miek@miek.nl", "@miekg", "*goog")
	addPerson("Miguel Molina", "hi@mvader.me", "@erizocosmico")
	addPerson("Mihai Borobocea", "MihaiBorobocea@gmail.com")
	addPerson("Mike Appleby", "mike@app.leby.org", "@appleby")
	addPerson("Mike Danese", "mikedanese@google.com", "@mikedanese")
	addPerson("Mike Houston", "mike@kothar.net", "@kothar")
	addPerson("Mike Lloyd", "kevin.michael.lloyd@gmail.com")
	addPerson("Mike Rosset", "mike.rosset@gmail.com", "@mrosset")
	addPerson("Mike Samuel", "mikesamuel@gmail.com", "@mikesamuel")
	addPerson("Mike Solomon", "msolo@gmail.com", "@msolo")
	addPerson("Mike Strosaker", "strosake@us.ibm.com")
	addPerson("Mike Wiacek", "mjwiacek@google.com", "@mikewiacek")
	addPerson("Mikhail Gusarov", "dottedmag@dottedmag.net", "@dottedmag")
	addPerson("Miki Habryn", "dichro@rcpt.to")
	addPerson("Miki Tebeka", "miki.tebeka@gmail.com", "@tebeka")
	addPerson("Mikio Hara", "mikioh.mikioh@gmail.com", "@mikioh")
	addPerson("Mikkel Krautz", "mikkel@krautz.dk", "@mkrautz")
	addPerson("Miquel Sabaté Solà", "mikisabate@gmail.com", "@mssola")
	addPerson("Miroslav Genov", "mgenov@gmail.com", "@mgenov")
	addPerson("Mitchell-Riley", "tug72074@temple.edu")
	addPerson("Miyakawa Taku", "miyakawa.taku@gmail.com")
	addPerson("Mohit Agarwal", "mohit@sdf.org", "@0xmohit")
	addPerson("Momchil Velikov", "momchil.velikov@gmail.com", "@momchil-velikov")
	addPerson("Monis Khan", "mkhan@redhat.com", "@enj")
	addPerson("Monty Taylor", "mordred@inaugust.com", "@emonty")
	addPerson("Moriyoshi Koizumi", "mozo@mozo.jp", "@moriyoshi")
	addPerson("Morten Siebuhr", "sbhr@sbhr.dk", "@msiebuhr")
	addPerson("Mostyn Bramley-Moore", "mostyn@antipode.se")
	addPerson("Mrunal Patel", "mrunalp@gmail.com", "@mrunalp")
	addPerson("Muhammed Uluyol", "uluyol0@gmail.com", "@uluyol")
	addPerson("Mura Li", "mura_li@castech.com.tw", "@typeless")
	addPerson("Máximo Cuadros Ortiz", "mcuadros@gmail.com", "@mcuadros")
	addPerson("NODA, Kai", "nodakai@gmail.com")
	addPerson("Nan Deng", "monnand@gmail.com", "@monnand")
	addPerson("Nathan Caza", "mastercactapus@gmail.com", "@mastercactapus")
	addPerson("Nathan John Youngman", "nj@nathany.com", "@nathany")
	addPerson("Nathan Otterness", "otternes@cs.unc.edu")
	addPerson("Nathan P Finch", "nate.finch@gmail.com", "@natefinch")
	addPerson("Nathan VanBenschoten", "nvanbenschoten@gmail.com", "@nvanbenschoten")
	addPerson("Nathan Youngman", "git@nathany.com", "@nathany")
	addPerson("Nathan(yinian) Hu", "nathanhu@google.com", "@nathandfox")
	addPerson("Neelesh Chandola", "neelesh.c98@gmail.com")
	addPerson("Neil Lyons", "nwjlyons@googlemail.com", "@nwjlyons")
	addPerson("Nevins Bartolomeo", "nevins.bartolomeo@gmail.com", "@nevins-b")
	addPerson("Niall Sheridan", "nsheridan@gmail.com", "@nsheridan")
	addPerson("Nic Day", "nic.day@me.com", "@nicday")
	addPerson("Nicholas Anderson", "nick@miletwo.net")
	addPerson("Nicholas Katsaros", "nick@nickkatsaros.com", "@nkatsaros")
	addPerson("Nicholas Maniscalco", "nicholas@maniscalco.com")
	addPerson("Nicholas Presta", "nick@nickpresta.ca", "@nickpresta")
	addPerson("Nicholas Waples", "nwaples@gmail.com", "@nwaples")
	addPerson("Nick Cooper", "nmvc@google.com")
	addPerson("Nick Craig-Wood", "nick@craig-wood.com", "@ncw")
	addPerson("Nick Harper", "nharper@google.com")
	addPerson("Nick Kubala", "nkubala@google.com", "@nkubala")
	addPerson("Nick Patavalis", "nick.patavalis@gmail.com", "@npat-efault")
	addPerson("Nick Petroni", "npetroni@cs.umd.edu")
	addPerson("Nick Sullivan", "nicholas.sullivan@gmail.com", "@grittygrease")
	addPerson("Nicolas S. Dade", "nic.dade@gmail.com", "@nsd20463")
	addPerson("Nigel Kerr", "nigel.kerr@gmail.com", "@nigelkerr")
	addPerson("Nigel Tao", "nigeltao@golang.org", "@nigeltao")
	addPerson("Nik Nyby", "nnyby@columbia.edu", "@nikolas")
	addPerson("Niko Dziemba", "niko@dziemba.com", "@dziemba")
	addPerson("Nikolay Ponomarev", "itsnikolay@gmail.com")
	addPerson("Nikolay Turpitko", "nikolay@turpitko.com", "@nikolay-turpitko")
	addPerson("Nilesh Jagnik", "nileshj@google.com")
	addPerson("Nitin Patil", "patil16nit@gmail.com")
	addPerson("Noah Campbell", "noahcampbell@gmail.com")
	addPerson("Noble Johnson", "noblepoly@gmail.com")
	addPerson("Nodir Turakulov", "nodir@google.com", "@nodirt")
	addPerson("Norberto Lopes", "nlopes.ml@gmail.com", "@nlopes")
	addPerson("Odin Ugedal", "odin@ugedal.com", "@odinuge")
	addPerson("Oleg Bulatov", "dmage@yandex-team.ru", "@dmage")
	addPerson("Oleg Vakheta", "helginet@gmail.com", "@helginet")
	addPerson("Oleku Konko", "oleku.konko@gmail.com", "@olekukonko")
	addPerson("Oling Cat", "olingcat@gmail.com", "@OlingCat")
	addPerson("Oliver Hookins", "ohookins@gmail.com", "@ohookins")
	addPerson("Oliver Tonnhofer", "olt@bogosoft.com", "@olt")
	addPerson("Olivier Duperray", "duperray.olivier@gmail.com", "@dupoxy")
	addPerson("Olivier Poitrey", "rs@dailymotion.com", "@rs")
	addPerson("Olivier Poitrey", "rs@netflix.com")
	addPerson("Olivier Poitrey", "rs@rhapsodyk.net", "@rs")
	addPerson("Olivier Saingre", "osaingre@gmail.com", "@osaingre")
	addPerson("Omar Jarjur", "ojarjur@google.com")
	addPerson("OneOfOne", "oneofone@gmail.com", "@OneOfOne")
	addPerson("Osamu TONOMORI", "osamingo@gmail.com")
	addPerson("Pablo Lalloni", "plalloni@gmail.com", "@lalloni")
	addPerson("Paddy Foran", "paddy@secondbit.org", "@paddyforan")
	addPerson("Padraig Kitterick", "padraigkitterick@gmail.com", "@padraigkitterick")
	addPerson("Paolo Giarrusso", "p.giarrusso@gmail.com", "@Blaisorblade")
	addPerson("Paolo Martini", "mrtnpaolo@gmail.com", "@ear")
	addPerson("Parker Moore", "parkrmoore@gmail.com", "@parkr")
	addPerson("Pascal Corpet", "lascap@google.com")
	addPerson("Pascal S. de Kloe", "pascal@quies.net", "@pascaldekloe")
	addPerson("Patrick Gavlin", "pgavlin@gmail.com", "@pgavlin")
	addPerson("Patrick Higgins", "patrick.allen.higgins@gmail.com", "@patrick-higgins")
	addPerson("Patrick Lee", "pattyshack101@gmail.com", "@pattyshack")
	addPerson("Patrick Mezard", "patrick@mezard.eu", "@pmezard")
	addPerson("Patrick Mylund Nielsen", "patrick@patrickmn.com", "@patrickmn")
	addPerson("Patrick Pelletier", "pp.pelletier@gmail.com", "@skinp")
	addPerson("Patrick Riley", "pfr@google.com", "@pfrstg")
	addPerson("Patrick Smith", "pat42smith@gmail.com", "@pat42smith")
	addPerson("Paul A Querna", "paul.querna@gmail.com", "@pquerna")
	addPerson("Paul Borman", "borman@google.com", "@pborman")
	addPerson("Paul Chang", "paulchang@google.com", "@pchx")
	addPerson("Paul Hankin", "paulhankin@google.com")
	addPerson("Paul Jolly", "paul@myitcv.org.uk", "@myitcv")
	addPerson("Paul Lalonde", "paul.a.lalonde@gmail.com", "@paul-lalonde")
	addPerson("Paul Marks", "pmarks@google.com", "@pmarks-net")
	addPerson("Paul Meyer", "paul.meyer@microsoft.com", "@paulmey")
	addPerson("Paul Nasrat", "pnasrat@google.com")
	addPerson("Paul Querna", "pquerna@apache.org", "@pquerna")
	addPerson("Paul Rosania", "paul.rosania@gmail.com", "@paulrosania")
	addPerson("Paul Sbarra", "sbarra.paul@gmail.com", "@tones111")
	addPerson("Paul Smith", "paulsmith@pobox.com", "@paulsmith")
	addPerson("Paul Wankadia", "junyer@google.com", "@junyer")
	addPerson("Paul van Brouwershaven", "paul@vanbrouwershaven.com", "@vanbroup")
	addPerson("Paulo Casaretto", "pcasaretto@gmail.com", "@pcasaretto")
	addPerson("Paulo Flabiano Smorigo", "pfsmorigo@linux.vnet.ibm.com")
	addPerson("Pavlo Sumkin", "psumkin@mirantis.com")
	addPerson("Pavlo Sumkin", "ymkins@gmail.com")
	addPerson("Pawel Knap", "pawelknap88@gmail.com", "@ppknap")
	addPerson("Peng Gao", "peng.gao.dut@gmail.com")
	addPerson("Percy Wegmann", "ox.to.a.cart@gmail.com", "@oxtoacart")
	addPerson("Perry Abbott", "perry.j.abbott@gmail.com", "@pabbott0")
	addPerson("Petar Maymounkov", "petarm@gmail.com", "@petar")
	addPerson("Peter Armitage", "peter.armitage@gmail.com", "@pja")
	addPerson("Peter Armitage", "pja@google.com")
	addPerson("Peter Bourgon", "peter@bourgon.org", "@peterbourgon")
	addPerson("Peter Collingbourne", "pcc@google.com", "@pcc")
	addPerson("Peter Ebden", "peter.ebden@gmail.com")
	addPerson("Peter Froehlich", "peter.hans.froehlich@gmail.com", "@phf")
	addPerson("Peter Gonda", "pgonda@google.com")
	addPerson("Peter Gonda", "ptrgonda@gmail.com")
	addPerson("Peter Kieltyka", "peter.kieltyka@pressly.com")
	addPerson("Peter Kleiweg", "pkleiweg@xs4all.nl", "@pebbe")
	addPerson("Peter Mattis", "petermattis@gmail.com")
	addPerson("Peter McKenzie", "petermck@google.com", "@peter-mckenzie")
	addPerson("Peter Moody", "peter.moody@gmail.com")
	addPerson("Peter Moody", "pmoody@uber.com", "@pmoody-")
	addPerson("Peter Morjan", "pmorjan@gmail.com", "@pmorjan")
	addPerson("Peter Mundy", "go.peter.90@gmail.com", "@peterGo")
	addPerson("Peter Nguyen", "peter@mictis.com", "@pengux")
	addPerson("Peter Tseng", "ptseng@squareup.com", "@petertseng")
	addPerson("Peter Waldschmidt", "peter@waldschmidt.com", "@peterwald")
	addPerson("Peter Waller", "p@pwaller.net", "@pwaller")
	addPerson("Peter Weinberger", "pjw@golang.org", "pjw@google.com", "@pjweinb", "@pjweinbgo")
	addPerson("Peter Williams", "pwil3058@gmail.com", "@pwil3058")
	addPerson("Philip Børgesen", "philip.borgesen@gmail.com", "@PhilipBorgesen")
	addPerson("Philip Hofer", "phofer@umich.edu")
	addPerson("Philip K. Warren", "pkwarren@gmail.com", "@pkwarren")
	addPerson("Philippe Lafoucrière", "philippe.lafoucriere@gmail.com")
	addPerson("Pierre Durand", "pierredurand@gmail.com", "@pierrre")
	addPerson("Pierre Roullon", "pierre.roullon@gmail.com", "@proullon")
	addPerson("Pieter Droogendijk", "pieter@binky.org.uk", "@PieterD")
	addPerson("Pieterjan Lambein", "pieterjan@otainsight.com")
	addPerson("Pietro Gagliardi", "pietro10@mac.com", "@andlabs")
	addPerson("Prasanna Swaminathan", "prasanna@mediamath.com", "@pswaminathan")
	addPerson("Prashant Varanasi", "prashant@prashantv.com", "@prashantv")
	addPerson("Prashanth Pai", "ppai@redhat.com")
	addPerson("Preetam Jinka", "pj@preet.am", "@Preetam")
	addPerson("ProhtMeyhet", "sebastian@prohtmeyhet.de")
	addPerson("Péter Surányi", "speter.go1@gmail.com", "@speter")
	addPerson("Péter Szilágyi", "peterke@gmail.com", "@karalabe")
	addPerson("Qi Zhao", "zhaoq@google.com")
	addPerson("Quan Yong Zhai", "qyzhai@gmail.com", "@qyzhai")
	addPerson("Quentin Perez", "qperez@ocs.online.net", "@QuentinPerez")
	addPerson("Quentin Renard", "contact@asticode.com", "@asticode")
	addPerson("Quentin Smith", "quentin@golang.org")
	addPerson("Quentin Smith", "quentin@golang.org", "@quentinmit")
	addPerson("Quinn Slack", "sqs@sourcegraph.com", "@sqs")
	addPerson("Quoc-Viet Nguyen", "afelion@gmail.com", "@nqv")
	addPerson("Radu Berinde", "radu@cockroachlabs.com", "@RaduBerinde")
	addPerson("Rafal Jeczalik", "rjeczalik@gmail.com", "@rjeczalik")
	addPerson("Rahul Chaudhry", "rahulchaudhry@chromium.org", "@rahulchaudhry", "*goog")
	addPerson("Rajat Goel", "rajat.goel2010@gmail.com", "@rajatgoel")
	addPerson("Ralph Corderoy", "ralph@inputplus.co.uk")
	addPerson("Ramesh Dharan", "dharan@google.com")
	addPerson("Randy Reddig", "ydnar@shaderlab.com")
	addPerson("Raph Levien", "raph@google.com", "@raphlinus")
	addPerson("Raphael Geronimi", "raphael.geronimi@gmail.com", "@rgeronimi")
	addPerson("Raul Silvera", "rsilvera@google.com", "@rauls5382")
	addPerson("Ray Tung", "rtung@thoughtworks.com", "@raytung")
	addPerson("Raymond Kazlauskas", "raima220@gmail.com", "@Rhymond")
	addPerson("Rebecca Stambler", "rstambler@golang.org", "@stamblerre")
	addPerson("Reese Wilson", "reese@shinymayhem.com")
	addPerson("Reinaldo de Souza Jr", "juniorz@gmail.com", "@juniorz")
	addPerson("Remi Gillig", "remigillig@gmail.com", "@speps")
	addPerson("Rhys Hiltner", "rhys@justin.tv", "@rhysh")
	addPerson("Ricardo Padilha", "ricardospadilha@gmail.com", "@ricardopadilha")
	addPerson("Ricardo Smania", "ricsmania@gmail.com")
	addPerson("Richard Barnes", "rlb@ipv.sx")
	addPerson("Richard Crowley", "r@rcrowley.org", "@rcrowley")
	addPerson("Richard Dingwall", "rdingwall@gmail.com", "@rdingwall")
	addPerson("Richard Eric Gavaletz", "gavaletz@gmail.com", "@gavaletz")
	addPerson("Richard Gibson", "richard.gibson@gmail.com", "@gibson042")
	addPerson("Richard Miller", "miller.research@gmail.com")
	addPerson("Richard Musiol", "mail@richard-musiol.de", "@neelance")
	addPerson("Rick Arnold", "rickarnoldjr@gmail.com", "@rickar")
	addPerson("Rick Hudson", "rlh@golang.org", "@RLH")
	addPerson("Riku Voipio", "riku.voipio@linaro.org", "@suihkulokki")
	addPerson("Risto Jaakko Saarelma", "rsaarelm@gmail.com", "@rsaarelm")
	addPerson("Rob Bradford", "robert.bradford@intel.com")
	addPerson("Rob Earhart", "earhart@google.com")
	addPerson("Rob Pike", "r@golang.org", "@robpike")
	addPerson("Rob Strong", "robert.a.strong@gmail.com")
	addPerson("Robert Bittle", "guywithnose@gmail.com")
	addPerson("Robert Figueiredo", "robfig@gmail.com", "@robfig")
	addPerson("Robert Griesemer", "gri@golang.org", "gri@gri-macbookair.roam.corp.google.com", "@griesemer")
	addPerson("Robert Hencke", "robert.hencke@gmail.com", "@rhencke")
	addPerson("Robert Iannucci", "iannucci@google.com")
	addPerson("Robert Obryk", "robryk@gmail.com", "@robryk")
	addPerson("Robert Sesek", "rsesek@google.com", "@rsesek")
	addPerson("Robert Stepanek", "robert.stepanek@gmail.com", "@rsto")
	addPerson("Robert Xu", "robxu9@gmail.com")
	addPerson("Roberto Lublinerman Reitzes", "rluble@google.com", "@rluble")
	addPerson("Rodrigo Moraes de Oliveira", "rodrigo.moraes@gmail.com", "@moraes")
	addPerson("Rodrigo Rafael Monti Kochenburger", "divoxx@gmail.com", "@divoxx")
	addPerson("Roger Pau Monné", "royger@gmail.com", "@royger")
	addPerson("Roger Peppe", "rogpeppe@gmail.com", "@rogpeppe")
	addPerson("Roland Illig", "roland.illig@gmx.de")
	addPerson("Roland Shoemaker", "rolandshoemaker@gmail.com", "@rolandshoemaker")
	addPerson("Ron Hashimoto", "mail@h2so5.net", "@h2so5")
	addPerson("Ronald G. Minnich", "rminnich@gmail.com", "@rminnich")
	addPerson("Ross Light", "light@google.com", "@zombiezen")
	addPerson("Rowan Worth", "sqweek@gmail.com", "@sqweek")
	addPerson("Ruben Vermeersch", "ruben@rocketeer.be")
	addPerson("Rui Ueyama", "ruiu@google.com", "@rui314")
	addPerson("Russ Cox", "rsc@golang.org", "@rsc")
	addPerson("Russell Haering", "russellhaering@gmail.com", "@russellhaering")
	addPerson("Ryan Boehning", "ryan.boehning@apcera.com", "@y0ssar1an")
	addPerson("Ryan Brown", "ribrdb@google.com", "@ribrdb")
	addPerson("Ryan Hitchman", "hitchmanr@gmail.com", "@rmmh")
	addPerson("Ryan Lower", "rpjlower@gmail.com", "@ryanlower")
	addPerson("Ryan Seys", "ryan@ryanseys.com", "@ryanseys")
	addPerson("Ryan Slade", "ryanslade@gmail.com", "@ryanslade")
	addPerson("Ryan Thomas", "rnt@google.com")
	addPerson("Ryuzo Yamamoto", "ryuzo.yamamoto@gmail.com", "@dragon3")
	addPerson("Rémy Oudompheng", "oudomphe@phare.normalesup.org", "@remyoudompheng")
	addPerson("S.Çağlar Onur", "caglar@10ur.org", "@caglar10ur")
	addPerson("Sagiv Ofek", "sagiv4@gmail.com")
	addPerson("Sai Cheemalapati", "saicheems@google.com")
	addPerson("Salman Aljammaz", "s@0x65.net", "@saljam")
	addPerson("Sam Broughton", "sambroughton@hotmail.co.uk")
	addPerson("Sam Hug", "samuel.b.hug@gmail.com", "@samuelhug")
	addPerson("Sam Thorogood", "thorogood@google.com", "@samthor")
	addPerson("Sam Whited", "sam@samwhited.com", "@SamWhited")
	addPerson("Saman Barghi", "saman.b@gmail.com")
	addPerson("Sameer Ajmani", "sameer@golang.org", "@Sajmani")
	addPerson("Sami Commerot", "samic@google.com")
	addPerson("Samuel Cochran", "sj26@sj26.com")
	addPerson("Samuel Tan", "samueltan@google.com", "@stjj89")
	addPerson("Samuele Pedroni", "pedronis@lucediurna.net", "@pedronis")
	addPerson("Sandy McPherson", "sandyzwin6@gmail.com")
	addPerson("Sanjay Menakuru", "balasanjay@gmail.com", "@balasanjay")
	addPerson("Sarah Adams", "shadams@google.com", "shadams@shadams0.mtv.corp.google.com", "@adams-sarah")
	addPerson("Sascha Brawer", "sascha@brawer.ch", "@brawer")
	addPerson("Sasha Lionheart", "lionhearts@google.com")
	addPerson("Satyajit Ranjeev", "s@ranjeev.in")
	addPerson("Sawood Alam", "ibnesayeed@gmail.com")
	addPerson("Scott Bell", "scott@sctsm.com", "@sctb")
	addPerson("Scott Ferguson", "scottwferg@gmail.com", "@scottferg")
	addPerson("Scott Lawrence", "bytbox@gmail.com", "@bytbox")
	addPerson("Scott Mansfield", "smansfield@netflix.com", "@ScottMansfield")
	addPerson("Scott Pakin", "scott+gpg@pakin.org")
	addPerson("Sean Christopherson", "sean.j.christopherson@intel.com", "@sean-jc")
	addPerson("Sean Dolphin", "Sean.Dolphin@kpcompass.com")
	addPerson("Sean Harger", "sharger@google.com")
	addPerson("Sean Rees", "sean@erifax.org", "@seanrees")
	addPerson("SeanBurford", "sburford@google.com", "@sburford")
	addPerson("Sebastian Schuberth", "sschuberth@gmail.com")
	addPerson("Sebastien Binet", "seb.binet@gmail.com", "@sbinet")
	addPerson("Sergey 'SnakE' Gromov", "snake.scaly@gmail.com", "@snake-scaly")
	addPerson("Sergey Mishin", "sergeymishine@gmail.com", "@dartkron")
	addPerson("Serhat Şevki Dinçer", "jfcgauss@gmail.com")
	addPerson("Seth Hoenig", "seth.a.hoenig@gmail.com", "@shoenig")
	addPerson("Seth Shelnutt", "Shelnutt2@gmail.com")
	addPerson("Seth Vargo", "sethvargo@gmail.com", "@sethvargo")
	addPerson("Shahar Kohanim", "skohanim@gmail.com")
	addPerson("Shane Hansen", "shanemhansen@gmail.com", "@shanemhansen")
	addPerson("Shawn Pearce", "sop@google.com")
	addPerson("Shawn Walker-Salas", "shawn.walker@oracle.com", "@binarycrusader")
	addPerson("Shenghou Ma", "minux@golang.org", "minux.ma@gmail.com", "@minux")
	addPerson("Shinji Tanaka", "shinji.tanaka@gmail.com", "@stanaka")
	addPerson("Shintaro Kaneko", "kaneshin0120@gmail.com", "@kaneshin")
	addPerson("Shivakumar GN", "shivakumar.gn@gmail.com", "@shivakumargn")
	addPerson("Shun Fan", "sfan@google.com")
	addPerson("Silvan Jegen", "s.jegen@gmail.com", "@Shugyousha")
	addPerson("Simon Jefford", "simon.jefford@gmail.com", "@simonjefford")
	addPerson("Simon Johansson", "simon@simonjohansson.com")
	addPerson("Simon Rawet", "simon@rawet.se", "@KilledKenny")
	addPerson("Simon Thulbourn", "simon+github@thulbourn.com", "@sthulb")
	addPerson("Simon Whitehead", "chemnova@gmail.com", "@simon-whitehead")
	addPerson("Simone Carletti", "weppos@gmail.com")
	addPerson("Sina Siadat", "siadat@gmail.com", "@siadat")
	addPerson("Sokolov Yura", "funny.falcon@gmail.com", "@funny-falcon")
	addPerson("Song Gao", "song@gao.io", "@songgao")
	addPerson("Spencer Nelson", "s@spenczar.com", "@spenczar")
	addPerson("Spring Mc", "heresy.mc@gmail.com", "@mcspring")
	addPerson("Srdjan Petrovic", "spetrovic@google.com", "@spetrovic77")
	addPerson("Sridhar Venkatakrishnan", "sridhar@laddoo.net", "@sridharv")
	addPerson("Stan Schwertly", "stan@schwertly.com", "@Stantheman")
	addPerson("Stanislav Paskalev", "kshorg@gmail.com")
	addPerson("Stephen Gutekanst", "stephen.gutekanst@gmail.com")
	addPerson("Stephen McQuay (smcquay)", "stephen@mcquay.me", "@smcquay")
	addPerson("Stephen Searles", "stephens2424@gmail.com", "stephen.searles@gmail.com", "@stephens2424")
	addPerson("Stephen Sugden", "glurgle@gmail.com")
	addPerson("Stephen Weinberg", "stephen@q5comm.com", "stephenmw@google.com", "@stephenmw")
	addPerson("Steve Francia", "spf@golang.org", "@spf13")
	addPerson("Steve McCoy", "mccoyst@gmail.com", "@mccoyst")
	addPerson("Steve Phillips", "steve@tryingtobeawesome.com", "@elimisteve")
	addPerson("Steve Reed", "sreed@zulily.com")
	addPerson("Steve Streeting", "steve@stevestreeting.com", "@sinbad")
	addPerson("Steve Wills", "steve@mouf.net")
	addPerson("Steven Buss", "sbuss@google.com")
	addPerson("Steven Elliot Harris", "seharris@gmail.com", "@seh")
	addPerson("Steven Erenst", "stevenerenst@gmail.com")
	addPerson("Steven Hartland", "steven.hartland@multiplay.co.uk", "@stevenh")
	addPerson("Steven Wilkin", "stevenwilkin@gmail.com", "@stevenwilkin")
	addPerson("Stéphane Travostino", "stephane.travostino@gmail.com", "@1player")
	addPerson("Sugu Sougoumarane", "ssougou@gmail.com", "@sougou")
	addPerson("Suharsh Sivakumar", "suharshs@google.com", "@suharshs")
	addPerson("Surma Surma", "surma@google.com")
	addPerson("Suyash", "dextrous93@gmail.com", "@suyash")
	addPerson("Sven Almgren", "sven@tras.se", "@blindmatrix")
	addPerson("Sven Blumenstein", "svbl@google.com")
	addPerson("Sven Dowideit", "svendowideit@home.org.au")
	addPerson("Syohei YOSHIDA", "syohex@gmail.com", "@syohex")
	addPerson("Sébastien Paolacci", "sebastien.paolacci@gmail.com", "@spaolacci")
	addPerson("Tad Glines", "tad.glines@gmail.com", "@tadglines")
	addPerson("Taj Khattra", "taj.khattra@gmail.com", "@tkhattra")
	addPerson("Takashi Matsuo", "tmatsuo@google.com")
	addPerson("Takuto Ikuta", "tikuta@google.com", "@atetubou")
	addPerson("Takuya Sato", "takuya0219@gmail.com")
	addPerson("Takuya Ueda", "uedatakuya@gmail.com", "@tenntenn")
	addPerson("Tal Shprecher", "tshprecher@gmail.com", "@tshprecher")
	addPerson("Tamir Duberstein", "tamird@gmail.com", "@tamird")
	addPerson("Tamás Gulácsi", "tgulacsi78@gmail.com")
	addPerson("Tarmigan Casebolt", "tarmigan@gmail.com")
	addPerson("Tarrant", "tarrant@keyneston.com", "@tarrant")
	addPerson("Taru Karttunen", "taruti@taruti.net", "@taruti")
	addPerson("Tatsuhiro Tsujikawa", "tatsuhiro.t@gmail.com", "@tatsuhiro-t")
	addPerson("Ted Hahn", "teh@uber.com")
	addPerson("Ted Kornish", "golang@tedkornish.com", "@tedkornish")
	addPerson("Terrel Shumway", "gopher@shumway.us")
	addPerson("Tetsuo Kiso", "tetsuokiso9@gmail.com", "@tetsuok")
	addPerson("Than McIntosh", "thanm@google.com", "@thanm")
	addPerson("Theo Schlossnagle", "jesus@lethargy.org")
	addPerson("Thiago Farina", "tfarina@chromium.org")
	addPerson("Thiago Fransosi Farina", "thiago.farina@gmail.com", "@thiagofarina")
	addPerson("Thibaut Colar", "tcolar@colar.net")
	addPerson("Thomas Alan Copeland", "talan.copeland@gmail.com", "@talanc")
	addPerson("Thomas Bonfort", "thomas.bonfort@gmail.com", "@tbonfort")
	addPerson("Thomas Bouldin", "inlined@google.com")
	addPerson("Thomas Desrosiers", "thomasdesr@gmail.com", "@thomaso-mirodin")
	addPerson("Thomas Habets", "habets@google.com", "@ThomasHabets")
	addPerson("Thomas Johnson", "NTmatter@gmail.com")
	addPerson("Thomas Kappler", "tkappler@gmail.com", "@thomas11")
	addPerson("Thomas de Zeeuw", "thomasdezeeuw@gmail.com", "@Thomasdezeeuw")
	addPerson("Thorben Krueger", "thorben.krueger@gmail.com", "@benthor")
	addPerson("Thordur Bjornsson", "thorduri@secnorth.net", "@thorduri")
	addPerson("Tilman Dilo", "tilman.dilo@gmail.com", "@tdilo")
	addPerson("Tim 'mithro' Ansell", "tansell@google.com")
	addPerson("Tim Cooijmans", "timcooijmans@gmail.com", "@timcooijmans")
	addPerson("Tim Ebringer", "tim.ebringer@gmail.com")
	addPerson("Tim Henderson", "tim.tadh@gmail.com", "@timtadh")
	addPerson("Tim Hockin", "thockin@google.com", "@thockin")
	addPerson("Tim Shen", "timshen@google.com", "@timshen91")
	addPerson("Tim Swast", "swast@google.com", "@tswast")
	addPerson("Timo Savola", "timo.savola@gmail.com", "@tsavola")
	addPerson("Timothy Studd", "tim@timstudd.com", "@timstudd")
	addPerson("Tipp Moseley", "tipp@google.com", "@tippjammer")
	addPerson("Tobias Columbus", "tobias.columbus@gmail.com", "@tc-0")
	addPerson("Toby Burress", "kurin@google.com")
	addPerson("Todd Neal", "todd@tneal.org", "@tzneal")
	addPerson("Todd Rafferty", "webRat@gmail.com")
	addPerson("Todd Wang", "toddwang@gmail.com", "@tatatodd")
	addPerson("Tom Bergan", "tombergan@google.com", "@tombergan")
	addPerson("Tom Heng", "zhm20070928@gmail.com", "@tomheng")
	addPerson("Tom Linford", "tomlinford@gmail.com", "@tomlinford")
	addPerson("Tom Wilkie", "tom.wilkie@gmail.com", "tom@weave.works", "@tomwilkie")
	addPerson("Tommy Schaefer", "tommy.schaefer@teecom.com", "@tommyschaefer")
	addPerson("Tonis Tiigi", "tonistiigi@gmail.com", "@tonistiigi")
	addPerson("Tor Andersson", "tor.andersson@gmail.com", "@ccxvii")
	addPerson("Tormod Erevik Lea", "tormodlea@gmail.com", "@tormoder")
	addPerson("Trey Lawrence", "lawrence.trey@gmail.com", "@TreyLawrence")
	addPerson("Tristan Colgate", "tcolgate@gmail.com", "@tcolgate")
	addPerson("Tristan Ooohry", "ooohry@gmail.com", "@golantrevize")
	addPerson("Tristan Rice", "rice@fn.lc")
	addPerson("Trung Nguyen", "trung.n.k@gmail.com")
	addPerson("Tuo Shan", "shantuo@google.com", "@shantuo")
	addPerson("Tuo Shan", "sturbo89@gmail.com")
	addPerson("Tw", "tw19881113@gmail.com", "@tw4452852")
	addPerson("Tyler Bunnell", "tylerbunnell@gmail.com", "@tylerb")
	addPerson("Tyler Treat", "ttreat31@gmail.com")
	addPerson("Tzu-Jung Lee", "roylee17@currant.com", "@roylee17")
	addPerson("Ugorji Nwoke", "ugorji@gmail.com", "@ugorji")
	addPerson("Ulrich Kunitz", "uli.kunitz@gmail.com", "@ulikunitz")
	addPerson("Uriel Mangado", "uriel@berlinblue.org", "@uriel")
	addPerson("Uttam C Pawar", "uttam.c.pawar@intel.com", "@uttampawar")
	addPerson("Vadim Grek", "vadimprog@gmail.com", "@brainiac84")
	addPerson("Vega Garcia Luis Alfonso", "vegacom@gmail.com", "@vegacom")
	addPerson("Victor Chudnovsky", "vchudnov@google.com")
	addPerson("Victor Vrantchan", "vrancean+github@gmail.com", "@groob")
	addPerson("Vikas Kedia", "vikask@google.com")
	addPerson("Vincent Batts", "vbatts@hashbangbash.com", "@vbatts")
	addPerson("Vincent Demeester", "vinc.demeester@gmail.com")
	addPerson("Vincent Vanackere", "vincent.vanackere@gmail.com", "@vanackere")
	addPerson("Vinu Rajashekhar", "vinutheraj@gmail.com", "@vinuraja")
	addPerson("Vishvananda Ishaya", "vishvananda@gmail.com", "@vishvananda")
	addPerson("Vitor De Mario", "vitordemario@gmail.com", "@vdemario")
	addPerson("Vivek Sekhar", "vivek@viveksekhar.ca")
	addPerson("Vlad Krasnov", "vlad@cloudflare.com", "@vkrasnov")
	addPerson("Vladimir Mihailenco", "vladimir.webdev@gmail.com", "@vmihailenco")
	addPerson("Vladimir Nikishenko", "vova616@gmail.com", "@vova616")
	addPerson("Vladimir Stefanovic", "vladimir.stefanovic@imgtec.com", "@vstefanovic")
	addPerson("Volker Dobler", "dr.volker.dobler@gmail.com", "@vdobler")
	addPerson("Volodymyr Paprotski", "vpaprots@ca.ibm.com", "@vpaprots")
	addPerson("Walter Poupore", "wpoupore@google.com")
	addPerson("Wander Lairson Costa", "wcosta@mozilla.com", "@walac")
	addPerson("Wedson Almeida Filho", "wedsonaf@google.com", "@wedsonaf")
	addPerson("Wei Guangjing", "vcc.163@gmail.com", "@wgj-zz")
	addPerson("Wei Xiao", "wei.xiao@arm.com", "@williamweixiao")
	addPerson("Weichao Tang", "tevic.tt@gmail.com")
	addPerson("Weichao Tang", "tevic.tt@gmail.com", "@Tevic")
	addPerson("Will Chan", "willchan@google.com")
	addPerson("Will Norris", "willnorris@google.com", "@willnorris")
	addPerson("Will Storey", "will@summercat.com", "@horgh")
	addPerson("Willem van der Schyff", "willemvds@gmail.com", "@willemvds")
	addPerson("William Chan", "willchan@chromium.org", "@willchan", "*goog")
	addPerson("William Orr", "will@worrbase.com", "@worr")
	addPerson("Wisdom Omuya", "deafgoat@gmail.com", "@deafgoat")
	addPerson("XAX", "xaxiclouddev@gmail.com")
	addPerson("Xia Bin", "snyh@snyh.org", "@snyh")
	addPerson("Xing Xing", "mikespook@gmail.com", "@mikespook")
	addPerson("Xudong Zhang", "felixmelon@gmail.com")
	addPerson("Xuyang Kang", "xuyang@google.com")
	addPerson("Xuyang Kang", "xuyangkang@gmail.com", "@xuyangkang")
	addPerson("Yaacov Akiba Slama", "yaslama@gmail.com")
	addPerson("Yann Kerhervé", "yann.kerherve@gmail.com", "@yannk")
	addPerson("Yao Zhang", "lunaria21@gmail.com", "@cherrymui")
	addPerson("Yasha Bubnov", "girokompass@gmail.com")
	addPerson("Yasuharu Goto", "matope.ono@gmail.com", "@matope")
	addPerson("Yasuhiro Matsumoto", "mattn.jp@gmail.com", "@mattn")
	addPerson("Yestin", "ylh@pdx.edu", "@ylih")
	addPerson("Yesudeep Mangalapilly", "yesudeep@google.com", "@gorakhargosh")
	addPerson("Yissakhar Z. Beck", "yissakhar.beck@gmail.com", "@DeedleFake")
	addPerson("Yongjian Xu", "i3dmaster@gmail.com", "@i3d")
	addPerson("Yoon", "learder@gmail.com")
	addPerson("Yoshiyuki Kanno", "nekotaroh@gmail.com", "@mocchira")
	addPerson("Yuki Yugui Sonoda", "yugui@google.com")
	addPerson("Yusuke Kagiwada", "block.rxckin.beats@gmail.com", "@Jxck")
	addPerson("Yuusei Kuwana", "kuwana@kumama.org", "@kumama")
	addPerson("Yuval Pavel Zholkover", "paulzhol@gmail.com", "@paulzhol")
	addPerson("Yves Junqueira", "yves.junqueira@gmail.com", "@nictuku")
	addPerson("Zac Bergquist", "zbergquist99@gmail.com", "@zmb3")
	addPerson("Zach Bintliff", "zbintliff@gmail.com", "@zbintliff")
	addPerson("Zero King", "l2d4y3@gmail.com")
	addPerson("Zev Goldstein", "zev.goldstein@gmail.com", "@zevdg")
	addPerson("Zezhou Yu", "ray.zezhou@gmail.com")
	addPerson("Zhang Wei", "zhangwei198900@gmail.com")
	addPerson("Zheng Xu", "zheng.xu@arm.com")
	addPerson("ZhiFeng Hu", "hufeng1987@gmail.com")
	addPerson("Zhongwei Yao", "zhongwei.yao@arm.com", "@zhongweiy")
	addPerson("Ziad Hatahet", "hatahet@gmail.com", "@hatahet")
	addPerson("Zorion Arrizabalaga", "zorionk@gmail.com", "@zorion")
	addPerson("acoshift", "acoshift@gmail.com")
	addPerson("aecdanjun", "aeciodantasjunior@gmail.com", "@aecdanjun")
	addPerson("ajackura", "ajackura@localhost")
	addPerson("anatoly techtonik", "techtonik@gmail.com")
	addPerson("andrew werner", "andrew@upthere.com")
	addPerson("andrey mirtchovski", "mirtchovski@gmail.com", "@mirtchovski")
	addPerson("apoorvam", "app.apoorva@gmail.com")
	addPerson("areski", "areski@gmail.com", "@areski")
	addPerson("avi", "hi@avi.im")
	addPerson("awaw fumin", "awawfumin@gmail.com", "@fumin")
	addPerson("ayanamist", "ayanamist@gmail.com", "@ayanamist")
	addPerson("benjamin-rood", "bisr@icloud.com")
	addPerson("bogem", "albertnigma@gmail.com", "@bogem")
	addPerson("boreq", "boreq@sourcedrops.com")
	addPerson("c9s", "yoanlin93@gmail.com", "@c9s")
	addPerson("datianshi", "dsz0111@gmail.com", "@datianshi")
	addPerson("djherbis", "djherbis@gmail.com", "@djherbis")
	addPerson("elmar", "ktye78@gmail.com")
	addPerson("emersion", "contact@emersion.fr")
	addPerson("erdi", "erdi@google.com")
	addPerson("feilengcui008", "feilengcui008@gmail.com", "@feilengcui008")
	addPerson("ferhat elmas", "elmas.ferhat@gmail.com")
	addPerson("garrickevans", "garrick@google.com")
	addPerson("gbbr", "ga@stripetree.co.uk", "@gbbr")
	addPerson("glorieux", "lorieux.g@gmail.com", "@glorieux")
	addPerson("gulyasm", "mgulyas86@gmail.com", "@gulyasm")
	addPerson("halgrimur", "douga@google.com")
	addPerson("haya14busa", "haya14busa@gmail.com", "@haya14busa")
	addPerson("haya14busa", "hayabusa1419@gmail.com", "@haya14busa")
	addPerson("hsinhoyeh", "yhh92u@gmail.com")
	addPerson("iamqizhao", "toqizhao@gmail.com")
	addPerson("jerome-laforge", "jerome.laforge@gmail.Com")
	addPerson("joshua stein", "jcs@jcs.org")
	addPerson("kargakis", "mkargaki@redhat.com", "@kargakis")
	addPerson("khr", "khr@khr-glaptop.roam.corp.google.com")
	addPerson("kim yongbin", "kybinz@gmail.com", "@kybin")
	addPerson("kortschak", "dan.kortschak@adelaide.edu.au", "@kortschak")
	addPerson("kujenga", "ataylor0123@gmail.com")
	addPerson("ltnwgl", "ltnwgl@gmail.com")
	addPerson("mattyw", "gh@mattyw.net", "@mattyw")
	addPerson("mdp", "m@mdp.im")
	addPerson("mihasya", "m@mihasya.com", "@mihasya")
	addPerson("mike andrews", "mra@xoba.com", "@xoba")
	addPerson("mischief", "mischief@offblast.org", "@mischief")
	addPerson("molivier", "olivier.matthieu@gmail.com", "@molivier")
	addPerson("mpl", "mathieu.lonjaret@gmail.com", "@mpl")
	addPerson("mstrong", "mstrong1341@gmail.com", "@xmattstrongx")
	addPerson("musgravejw", "musgravejw@gmail.com")
	addPerson("nicerobot", "golang@nicerobot.org")
	addPerson("nick.grange", "nicolas.grange@retrievercommunications.com")
	addPerson("nobonobo", "irieda@gmail.com", "@nobonobo")
	addPerson("nwidger", "niels.widger@gmail.com", "@nwidger")
	addPerson("oiooj", "nototon@gmail.com")
	addPerson("pavel-paulau", "pavel.paulau@gmail.com", "@pavel-paulau")
	addPerson("pbberlin", "peter.buchmann@web.de")
	addPerson("philhofer", "phofer@umich.edu", "@philhofer")
	addPerson("qeed", "qeed.quan@gmail.com", "@qeedquan")
	addPerson("robnorman", "rob.norman@infinitycloud.com", "@robnorman")
	addPerson("rubyist", "scott.barron@github.com", "@rubyist")
	addPerson("sam boyer", "tech@samboyer.org", "@sdboyer")
	addPerson("sasha-s", "sasha@scaledinference.com")
	addPerson("sdheisenberg", "nicholasleli@gmail.com", "@smugcloud")
	addPerson("sergey.arseev", "sergey.arseev@intel.com", "@sergeyarseev")
	addPerson("shaharko", "skohanim@gmail.com", "@skohanim")
	addPerson("shawnps", "shawnpsmith@gmail.com", "@shawnps")
	addPerson("slene", "vslene@gmail.com")
	addPerson("stxmendez", "stxmendez@gmail.com")
	addPerson("tal@whatexit.org", "tal@whatexit.org")
	addPerson("telecoda", "robbaines@gmail.com")
	addPerson("theairkit", "theairkit@gmail.com")
	addPerson("themihai", "mihai@epek.com")
	addPerson("thoeni", "thoeni@gmail.com")
	addPerson("tliu", "terry.liu.y@gmail.com")
	addPerson("tnt", "alkaloid.btx@gmail.com", "@trtstm")
	addPerson("tro3", "trey.roessig@gmail.com", "@tro3")
	addPerson("ttacon", "ttacon@gmail.com", "@ttacon")
	addPerson("ttyh061", "ttyh061@gmail.com")
	addPerson("unknown", "daria.kolistratova@intel.com", "@DarKol13")
	addPerson("unknown", "nonamezeil@gmail.com", "@zeil")
	addPerson("voutasaurus", "voutasaurus@gmail.com", "@voutasaurus")
	addPerson("vvakame", "vvakame+dev@gmail.com")
	addPerson("wbond", "will@wbond.net")
	addPerson("wheelcomplex yin", "wheelcomplex@gmail.com")
	addPerson("woodsaj", "awoods@raintank.io", "@woodsaj")
	addPerson("xiezhenye", "xiezhenye@gmail.com")
	addPerson("xufei_Alex", "badgangkiller@gmail.com", "@knightXun")
	addPerson("yanyiwu", "wuyanyi09@gmail.com")
	addPerson("yazver", "ya.zver@gmail.com")
	addPerson("zachgersh", "zachgersh@gmail.com")
	addPerson("Özgür Kesim", "oec-go@kesim.org")
	addPerson("Максим Федосеев", "max.faceless.frei@gmail.com", "@codesenberg")
	addPerson("Фахриддин Балтаев", "faxriddinjon@gmail.com", "@faxriddin")
	addPerson("张嵩", "zs349596@gmail.com", "@zs1379")
}

// GithubOfGomoteUser returns the GitHub username for the provided gomote user.
func GithubOfGomoteUser(gomoteUser string) (githubUser string) {
	switch gomoteUser {
	case "austin":
		return "aclements"
	case "cbro":
		return "broady"
	case "cherryyz":
		return "cherrymui"
	case "cmang":
		return "paranoiacblack"
	case "drchase":
		return "dr2chase"
	case "gri":
		return "griesemer"
	case "hakim":
		return "hyangah"
	case "herbie":
		return "cybrcodr"
	case "iant":
		return "ianlancetaylor"
	case "jbd":
		return "rakyll"
	case "joetsai":
		return "dsnet"
	case "jrjohnson":
		return "johnsonj"
	case "khr":
		return "randall77"
	case "lazard":
		return "davidlazar"
	case "pjw":
		return "pjweinbgo"
	case "r":
		return "robpike"
	case "rstambler":
		return "stamblerre"
	case "sameer":
		return "Sajmani"
	case "shadams":
		return "adams-sarah"
	case "spf":
		return "spf13"
	}
	return gomoteUser
}
